# Copyright (c) 2023 Darren Erik Vengroff
"""Places in California."""


ACALANES_RIDGE_CDP = "00135"
ACAMPO_CDP = "00156"
ACTON_CDP = "00212"
ADELANTO_CITY = "00296"
ADIN_CDP = "00310"
AGOURA_HILLS_CITY = "00394"
AGUA_DULCE_CDP = "00450"
AGUANGA_CDP = "00464"
AHWAHNEE_CDP = "00478"
AIRPORT_CDP = "00535"
ALAMEDA_CITY = "00562"
ALAMO_CDP = "00618"
ALBANY_CITY = "00674"
ALBION_CDP = "00716"
ALDERPOINT_CDP = "00786"
ALHAMBRA_VALLEY_CDP = "00898"
ALHAMBRA_CITY = "00884"
ALISO_VIEJO_CITY = "00947"
ALLEGHANY_CDP = "00982"
ALLENDALE_CDP = "00996"
ALLENSWORTH_CDP = "01010"
ALMANOR_CDP = "01094"
ALONDRA_PARK_CDP = "01150"
ALPAUGH_CDP = "01164"
ALPINE_CDP = "01192"
ALPINE_VILLAGE_CDP = "01228"
ALTA_CDP = "01276"
ALTA_SIERRA_CDP_KERN_COUNTY = "01358"
ALTA_SIERRA_CDP_NEVADA_COUNTY = "01360"
ALTADENA_CDP = "01290"
ALTO_CDP = "01416"
ALTURAS_CITY = "01444"
ALUM_ROCK_CDP = "01458"
AMADOR_CITY_CITY = "01514"
AMADOR_PINES_CDP = "01518"
AMERICAN_CANYON_CITY = "01640"
AMESTI_CDP = "01651"
ANAHEIM_CITY = "02000"
ANCHOR_BAY_CDP = "02028"
ANDERSON_CITY = "02042"
ANGELS_CITY = "02112"
ANGWIN_CDP = "02168"
ANTELOPE_CDP = "02210"
ANTIOCH_CITY = "02252"
ANZA_CDP = "02294"
APPLE_VALLEY_TOWN = "02364"
APTOS_CDP = "02378"
APTOS_HILLS_LARKIN_VALLEY_CDP = "02382"
ARBUCKLE_CDP = "02420"
ARCADIA_CITY = "02462"
ARCATA_CITY = "02476"
ARDEN_ARCADE_CDP = "02553"
ARMONA_CDP = "02700"
ARNOLD_CDP = "02770"
AROMAS_CDP = "02812"
ARROYO_GRANDE_CITY = "02868"
ARTESIA_CITY = "02896"
ARTOIS_CDP = "02910"
ARVIN_CITY = "02924"
ASHLAND_CDP = "02980"
ASPEN_SPRINGS_CDP = "03026"
ATASCADERO_CITY = "03064"
ATHERTON_TOWN = "03092"
ATWATER_CITY = "03162"
AUBERRY_CDP = "03190"
AUBURN_LAKE_TRAILS_CDP = "03205"
AUBURN_CITY = "03204"
AUGUST_CDP = "03209"
AVALON_CITY = "03274"
AVENAL_CITY = "03302"
AVERY_CDP = "03316"
AVILA_BEACH_CDP = "03330"
AVOCADO_HEIGHTS_CDP = "03344"
AZUSA_CITY = "03386"
BAKER_CDP = "03512"
BAKERSFIELD_COUNTRY_CLUB_CDP = "03546"
BAKERSFIELD_CITY = "03526"
BALDWIN_PARK_CITY = "03666"
BALLARD_CDP = "03694"
BALLICO_CDP = "03708"
BANGOR_CDP = "03792"
BANNING_CITY = "03820"
BARSTOW_CITY = "04030"
BASS_LAKE_CDP = "04198"
BAY_POINT_CDP = "04415"
BAYVIEW_CDP_CONTRA_COSTA_COUNTY = "04470"
BAYVIEW_CDP_HUMBOLDT_COUNTY = "04478"
BAYWOOD_PARK_CDP = "04549"
BEALE_AFB_CDP = "04576"
BEAR_CREEK_CDP = "04632"
BEAR_VALLEY_CDP_ALPINE_COUNTY = "04716"
BEAR_VALLEY_CDP_MARIPOSA_COUNTY = "04730"
BEAR_VALLEY_SPRINGS_CDP = "04734"
BEAUMONT_CITY = "04758"
BECKWOURTH_CDP = "04772"
BELDEN_CDP = "04856"
BELL_CANYON_CDP = "04938"
BELL_GARDENS_CITY = "04996"
BELL_CITY = "04870"
BELLA_VISTA_CDP = "04926"
BELLFLOWER_CITY = "04982"
BELMONT_CITY = "05108"
BELVEDERE_CITY = "05164"
BEN_LOMOND_CDP = "05332"
BENBOW_CDP = "05262"
BEND_CDP = "05276"
BENICIA_CITY = "05290"
BENTON_CDP = "05346"
BENTON_PARK_CDP = "05356"
BERKELEY_CITY = "06000"
BERMUDA_DUNES_CDP = "06028"
BERRY_CREEK_CDP = "06070"
BERTSCH_OCEANVIEW_CDP = "06150"
BETHEL_ISLAND_CDP = "06210"
BEVERLY_HILLS_CITY = "06308"
BIEBER_CDP = "06336"
BIG_BEAR_CITY_CDP = "06406"
BIG_BEAR_LAKE_CITY = "06434"
BIG_BEND_CDP = "06475"
BIG_CREEK_CDP = "06518"
BIG_LAGOON_CDP = "06567"
BIG_PINE_CDP = "06616"
BIG_RIVER_CDP = "06635"
BIGGS_CITY = "06560"
BIOLA_CDP = "06728"
BISHOP_CITY = "06798"
BLACK_POINT_GREEN_POINT_CDP = "06982"
BLACKHAWK_CDP = "06928"
BLACKLAKE_CDP = "06935"
BLAIRSDEN_CDP = "06994"
BLOOMFIELD_CDP = "07036"
BLOOMINGTON_CDP = "07064"
BLUE_LAKE_CITY = "07162"
BLUEWATER_CDP = "07172"
BLYTHE_CITY = "07218"
BODEGA_BAY_CDP = "07260"
BODEGA_CDP = "07246"
BODFISH_CDP = "07274"
BOLINAS_CDP = "07316"
BOMBAY_BEACH_CDP = "07372"
BONADELLE_RANCHOS_CDP = "07378"
BONITA_CDP = "07414"
BONNY_DOON_CDP = "07470"
BONSALL_CDP = "07498"
BOONVILLE_CDP = "07512"
BOOTJACK_CDP = "07525"
BORON_CDP = "07568"
BORONDA_CDP = "07578"
BORREGO_SPRINGS_CDP = "07596"
BOSTONIA_CDP = "07624"
BOULDER_CREEK_CDP = "07652"
BOULEVARD_CDP = "07694"
BOWLES_CDP = "07750"
BOYES_HOT_SPRINGS_CDP = "07848"
BRADBURY_CITY = "07946"
BRADLEY_CDP = "07974"
BRAWLEY_CITY = "08058"
BREA_CITY = "08100"
BRENTWOOD_CITY = "08142"
BRET_HARTE_CDP = "08172"
BRIDGEPORT_CDP = "08240"
BRISBANE_CITY = "08310"
BROADMOOR_CDP = "08338"
BROOKDALE_CDP = "08478"
BROOKS_CDP = "08506"
BROOKTRAILS_CDP = "08530"
BUCK_MEADOWS_CDP = "08716"
BUCKHORN_CDP = "08680"
BUCKS_LAKE_CDP = "08744"
BUELLTON_CITY = "08758"
BUENA_PARK_CITY = "08786"
BUENA_VISTA_CDP = "08828"
BURBANK_CDP = "08968"
BURBANK_CITY = "08954"
BURLINGAME_CITY = "09066"
BURNEY_CDP = "09122"
BURNT_RANCH_CDP = "09150"
BUTTE_CREEK_CANYON_CDP = "09310"
BUTTE_MEADOWS_CDP = "09318"
BUTTE_VALLEY_CDP = "09324"
BUTTONWILLOW_CDP = "09332"
BYRON_CDP = "09346"
BYSTROM_CDP = "09353"
C_ROAD_CDP = "17267"
CABAZON_CDP = "09360"
CALABASAS_CITY = "09598"
CALEXICO_CITY = "09710"
CALIFORNIA_CITY_CITY = "09780"
CALIFORNIA_HOT_SPRINGS_CDP = "09822"
CALIFORNIA_PINES_CDP = "09834"
CALIFORNIA_POLYTECHNIC_STATE_UNIVERSITY_CDP = "09835"
CALIMESA_CITY = "09864"
CALIPATRIA_CITY = "09878"
CALISTOGA_CITY = "09892"
CALLENDER_CDP = "09948"
CALPELLA_CDP = "09990"
CALPINE_CDP = "10004"
CALWA_CDP = "10032"
CAMANCHE_NORTH_SHORE_CDP = "10042"
CAMANCHE_VILLAGE_CDP = "10044"
CAMARILLO_CITY = "10046"
CAMBRIA_CDP = "10074"
CAMBRIAN_PARK_CDP = "10088"
CAMERON_PARK_CDP = "10256"
CAMINO_CDP = "10270"
CAMINO_TASSAJARA_CDP = "10301"
CAMP_NELSON_CDP = "10494"
CAMP_PENDLETON_MAINSIDE_CDP = "10554"
CAMP_PENDLETON_SOUTH_CDP = "10561"
CAMPBELL_CITY = "10345"
CAMPO_CDP = "10508"
CAMPTONVILLE_CDP = "10676"
CANBY_CDP = "10732"
CANTUA_CREEK_CDP = "10816"
CANYON_LAKE_CITY = "10928"
CANYONDAM_CDP = "10914"
CAPITOLA_CITY = "11040"
CARIBOU_CDP = "11166"
CARLSBAD_CITY = "11194"
CARMEL_VALLEY_VILLAGE_CDP = "11324"
CARMEL_BY_THE_SEA_CITY = "11250"
CARMET_CDP = "11376"
CARMICHAEL_CDP = "11390"
CARNELIAN_BAY_CDP = "11418"
CARPINTERIA_CITY = "11446"
CARRICK_CDP = "11481"
CARSON_CITY = "11530"
CARTAGO_CDP = "11600"
CARUTHERS_CDP = "11614"
CASA_CONEJO_CDP = "11656"
CASA_LOMA_CDP = "11696"
CASA_DE_ORO_MOUNT_HELIX_CDP = "11691"
CASMALIA_CDP = "11754"
CASPAR_CDP = "11768"
CASSEL_CDP = "11782"
CASTAIC_CDP = "11796"
CASTELLA_CDP = "11824"
CASTLE_HILL_CDP = "11915"
CASTRO_VALLEY_CDP = "11964"
CASTROVILLE_CDP = "11978"
CATHEDRAL_CITY_CITY = "12048"
CATHEYS_VALLEY_CDP = "12062"
CAYUCOS_CDP = "12132"
CAZADERO_CDP = "12146"
CEDAR_FLAT_CDP = "12216"
CEDAR_RIDGE_CDP = "12300"
CEDAR_SLOPE_CDP = "12314"
CEDARVILLE_CDP = "12328"
CENTERVILLE_CDP_FRESNO_COUNTY = "12412"
CENTERVILLE_CDP_SHASTA_COUNTY = "12415"
CERES_CITY = "12524"
CERRITOS_CITY = "12552"
CHALFANT_CDP = "12594"
CHALLENGE_BROWNSVILLE_CDP = "12612"
CHANNEL_ISLANDS_BEACH_CDP = "12669"
CHARLESTON_VIEW_CDP = "12730"
CHARTER_OAK_CDP = "12734"
CHEROKEE_CDP = "12818"
CHEROKEE_STRIP_CDP = "12860"
CHERRY_VALLEY_CDP = "12916"
CHERRYLAND_CDP = "12902"
CHESTER_CDP = "12930"
CHICO_CITY = "13014"
CHILCOOT_VINTON_CDP = "13077"
CHINA_LAKE_ACRES_CDP = "13157"
CHINESE_CAMP_CDP = "13182"
CHINO_HILLS_CITY = "13214"
CHINO_CITY = "13210"
CHOCTAW_VALLEY_CDP = "13278"
CHOWCHILLA_CITY = "13294"
CHUALAR_CDP = "13364"
CHULA_VISTA_CITY = "13392"
CITRUS_CDP = "13560"
CITRUS_HEIGHTS_CITY = "13588"
CLAREMONT_CITY = "13756"
CLARKSBURG_CDP = "13784"
CLAY_CDP = "13854"
CLAYTON_CITY = "13882"
CLEAR_CREEK_CDP = "13910"
CLEARLAKE_OAKS_CDP = "13966"
CLEARLAKE_RIVIERA_CDP = "13985"
CLEARLAKE_CITY = "13945"
CLEONE_CDP = "14008"
CLIO_CDP = "14106"
CLIPPER_MILLS_CDP = "14148"
CLOVERDALE_CITY = "14190"
CLOVIS_CITY = "14218"
CLYDE_CDP = "14232"
COACHELLA_CITY = "14260"
COALINGA_CITY = "14274"
COARSEGOLD_CDP = "14288"
COBB_CDP = "14302"
COFFEE_CREEK_CDP = "14406"
COHASSET_CDP = "14442"
COLD_SPRINGS_CDP_EL_DORADO_COUNTY = "14450"
COLD_SPRINGS_CDP_TUOLUMNE_COUNTY = "14454"
COLEVILLE_CDP = "14484"
COLFAX_CITY = "14498"
COLLEGE_CITY_CDP = "14554"
COLLIERVILLE_CDP = "14708"
COLMA_TOWN = "14736"
COLOMA_CDP = "14764"
COLTON_CITY = "14890"
COLUMBIA_CDP = "14904"
COLUSA_CITY = "14946"
COMMERCE_CITY = "14974"
COMPTCHE_CDP = "15030"
COMPTON_CITY = "15044"
CONCORD_CITY = "16000"
CONCOW_CDP = "16035"
CONTRA_COSTA_CENTRE_CDP = "16090"
COPPEROPOLIS_CDP = "16210"
CORCORAN_CITY = "16224"
CORNING_CITY = "16322"
CORONA_CITY = "16350"
CORONADO_CITY = "16378"
CORONITA_CDP = "16420"
CORRALITOS_CDP = "16434"
CORTE_MADERA_TOWN = "16462"
COSTA_MESA_CITY = "16532"
COTATI_CITY = "16560"
COTO_DE_CAZA_CDP = "16580"
COTTONWOOD_CDP_KERN_COUNTY = "16623"
COTTONWOOD_CDP_SHASTA_COUNTY = "16630"
COULTERVILLE_CDP = "16644"
COUNTRY_CLUB_CDP = "16651"
COURTLAND_CDP = "16714"
COVELO_CDP = "16728"
COVINA_CITY = "16742"
COWAN_CDP = "16762"
CRESCENT_CITY_CITY = "17022"
CRESCENT_MILLS_CDP = "17050"
CRESSEY_CDP = "17078"
CREST_CDP = "17106"
CRESTLINE_CDP = "17162"
CRESTON_CDP = "17232"
CROCKETT_CDP = "17274"
CROMBERG_CDP = "17288"
CROWLEY_LAKE_CDP = "17372"
CROWS_LANDING_CDP = "17428"
CUDAHY_CITY = "17498"
CULVER_CITY_CITY = "17568"
CUPERTINO_CITY = "17610"
CUTLER_CDP = "17708"
CUTTEN_CDP = "17722"
CUYAMA_CDP = "17727"
CYPRESS_CITY = "17750"
DALES_CDP = "17876"
DALY_CITY_CITY = "17918"
DANA_POINT_CITY = "17946"
DANVILLE_TOWN = "17988"
DAPHNEDALE_PARK_CDP = "17995"
DARWIN_CDP = "18030"
DAVENPORT_CDP = "18086"
DAVIS_CITY = "18100"
DAY_VALLEY_CDP = "18153"
DEER_PARK_CDP = "18324"
DEL_AIRE_CDP = "18352"
DEL_DIOS_CDP = "18422"
DEL_MAR_CITY = "18506"
DEL_MONTE_FOREST_CDP = "18590"
DEL_REY_CDP = "18674"
DEL_REY_OAKS_CITY = "18688"
DEL_RIO_CDP = "18695"
DELANO_CITY = "18394"
DELFT_COLONY_CDP = "18450"
DELHI_CDP = "18464"
DELLEKER_CDP = "18485"
DENAIR_CDP = "18856"
DERBY_ACRES_CDP = "18926"
DESCANSO_CDP = "18940"
DESERT_CENTER_CDP = "18982"
DESERT_EDGE_CDP = "18986"
DESERT_HOT_SPRINGS_CITY = "18996"
DESERT_PALMS_CDP = "19022"
DESERT_SHORES_CDP = "19024"
DESERT_VIEW_HIGHLANDS_CDP = "19052"
DI_GIORGIO_CDP = "19248"
DIABLO_CDP = "19150"
DIABLO_GRANDE_CDP = "19155"
DIAMOND_BAR_CITY = "19192"
DIAMOND_SPRINGS_CDP = "19220"
DILLON_BEACH_CDP = "19262"
DINUBA_CITY = "19318"
DISCOVERY_BAY_CDP = "19339"
DIXON_LANE_MEADOWCREEK_CDP = "19406"
DIXON_CITY = "19402"
DOBBINS_CDP = "19416"
DOGTOWN_CDP = "19440"
DOLLAR_POINT_CDP = "19455"
DORRINGTON_CDP = "19570"
DORRIS_CITY = "19584"
DOS_PALOS_Y_CDP = "19654"
DOS_PALOS_CITY = "19612"
DOUGLAS_CITY_CDP = "19724"
DOWNEY_CITY = "19766"
DOWNIEVILLE_CDP = "19794"
DOYLE_CDP = "19878"
DRYTOWN_CDP = "19976"
DUARTE_CITY = "19990"
DUBLIN_CITY = "20018"
DUCOR_CDP = "20032"
DUNNIGAN_CDP = "20228"
DUNSMUIR_CITY = "20242"
DURHAM_CDP = "20270"
DUSTIN_ACRES_CDP = "20284"
DUTCH_FLAT_CDP = "20298"
EAGLEVILLE_CDP = "20424"
EARLIMART_CDP = "20438"
EAST_BAKERSFIELD_CDP = "20515"
EAST_FOOTHILLS_CDP = "20598"
EAST_HEMET_CDP = "20697"
EAST_LOS_ANGELES_CDP = "20802"
EAST_NICOLAUS_CDP = "20900"
EAST_NILES_CDP = "20903"
EAST_OAKDALE_CDP = "20907"
EAST_OROSI_CDP = "20942"
EAST_PALO_ALTO_CITY = "20956"
EAST_PASADENA_CDP = "20984"
EAST_PORTERVILLE_CDP = "21012"
EAST_QUINCY_CDP = "21026"
EAST_RANCHO_DOMINGUEZ_CDP = "21034"
EAST_RICHMOND_HEIGHTS_CDP = "21061"
EAST_SAN_GABRIEL_CDP = "21096"
EAST_SHORE_CDP = "21138"
EAST_SONORA_CDP = "21188"
EAST_TULARE_VILLA_CDP = "21210"
EAST_WHITTIER_CDP = "21292"
EASTERN_GOLETA_VALLEY_CDP = "20574"
EASTON_CDP = "20928"
EASTVALE_CITY = "21230"
EDGEWOOD_CDP = "21530"
EDISON_CDP = "21544"
EDMUNDSON_ACRES_CDP = "21558"
EDNA_CDP = "21565"
EDWARDS_AFB_CDP = "21600"
EL_ADOBE_CDP = "21691"
EL_CAJON_CITY = "21712"
EL_CENTRO_NAVAL_AIR_FACILITY_CDP = "21788"
EL_CENTRO_CITY = "21782"
EL_CERRITO_CDP = "21810"
EL_CERRITO_CITY = "21796"
EL_DORADO_HILLS_CDP = "21880"
EL_GRANADA_CDP = "21936"
EL_MACERO_CDP = "22104"
EL_MONTE_MOBILE_VILLAGE_CDP = "22235"
EL_MONTE_CITY = "22230"
EL_NIDO_CDP = "22286"
EL_PASO_DE_ROBLES_PASO_ROBLES_CITY = "22300"
EL_PORTAL_CDP = "22328"
EL_RANCHO_CDP = "22360"
EL_RIO_CDP = "22370"
EL_SEGUNDO_CITY = "22412"
EL_SOBRANTE_CDP_CONTRA_COSTA_COUNTY = "22454"
EL_SOBRANTE_CDP_RIVERSIDE_COUNTY = "22457"
EL_VERANO_CDP = "22510"
ELDRIDGE_CDP = "21894"
ELFIN_FOREST_CDP = "21916"
ELIZABETH_LAKE_CDP = "21964"
ELK_CREEK_CDP = "22006"
ELK_GROVE_CITY = "22020"
ELKHORN_CDP = "22034"
ELMIRA_CDP = "22146"
ELVERTA_CDP = "22524"
EMERALD_LAKE_HILLS_CDP = "22587"
EMERYVILLE_CITY = "22594"
EMPIRE_CDP = "22622"
ENCINITAS_CITY = "22678"
ESCALON_CITY = "22790"
ESCONDIDO_CITY = "22804"
ESPARTO_CDP = "22846"
ETNA_CITY = "22972"
EUCALYPTUS_HILLS_CDP = "23000"
EUREKA_CITY = "23042"
EXETER_CITY = "23126"
FAIR_OAKS_CDP = "23294"
FAIRBANKS_RANCH_CDP = "23150"
FAIRFAX_CDP = "23158"
FAIRFAX_TOWN = "23168"
FAIRFIELD_CITY = "23182"
FAIRHAVEN_CDP = "23196"
FAIRMEAD_CDP = "23210"
FAIRVIEW_CDP = "23350"
FALL_RIVER_MILLS_CDP = "23532"
FALLBROOK_CDP = "23462"
FARMERSVILLE_CITY = "23616"
FARMINGTON_CDP = "23630"
FELLOWS_CDP = "23812"
FELTON_CDP = "23826"
FERNDALE_CITY = "23910"
FETTERS_HOT_SPRINGS_AGUA_CALIENTE_CDP = "23973"
FIDDLETOWN_CDP = "23980"
FIELDBROOK_CDP = "24008"
FIELDS_LANDING_CDP = "24022"
FILLMORE_CITY = "24092"
FIREBAUGH_CITY = "24134"
FISH_CAMP_CDP = "24218"
FLORENCE_GRAHAM_CDP = "24477"
FLORIN_CDP = "24498"
FLORISTON_CDP = "24526"
FLOURNOY_CDP = "24568"
FOLSOM_CITY = "24638"
FONTANA_CITY = "24680"
FOOTHILL_FARMS_CDP = "24722"
FORBESTOWN_CDP = "24750"
FORD_CITY_CDP = "24764"
FOREST_MEADOWS_CDP = "24897"
FOREST_RANCH_CDP = "24918"
FORESTA_CDP = "24792"
FORESTHILL_CDP = "24834"
FORESTVILLE_CDP = "24960"
FORT_BIDWELL_CDP = "25030"
FORT_BRAGG_CITY = "25058"
FORT_DICK_CDP = "25086"
FORT_HUNTER_LIGGETT_CDP = "25093"
FORT_IRWIN_CDP = "25114"
FORT_JONES_CITY = "25128"
FORT_WASHINGTON_CDP = "25300"
FORTUNA_CITY = "25296"
FOSTER_CITY_CITY = "25338"
FOUNTAIN_VALLEY_CITY = "25380"
FOWLER_CITY = "25436"
FRANKLIN_CDP_MERCED_COUNTY = "25488"
FRANKLIN_CDP_SACRAMENTO_COUNTY = "25506"
FRAZIER_PARK_CDP = "25534"
FREEDOM_CDP = "25576"
FREEPORT_CDP = "25590"
FREMONT_CITY = "26000"
FRENCH_CAMP_CDP = "26028"
FRENCH_GULCH_CDP = "26056"
FRENCH_VALLEY_CDP = "26067"
FRESNO_CITY = "27000"
FRIANT_CDP = "27014"
FRUITDALE_CDP = "27080"
FRUITRIDGE_POCKET_CDP = "27130"
FULLER_ACRES_CDP = "27190"
FULLERTON_CITY = "28000"
FULTON_CDP = "28014"
FURNACE_CREEK_CDP = "28021"
GALT_CITY = "28112"
GARBERVILLE_CDP = "28154"
GARDEN_ACRES_CDP = "28182"
GARDEN_FARMS_CDP = "28210"
GARDEN_GROVE_CITY = "29000"
GARDENA_CITY = "28168"
GAREY_CDP = "29070"
GARNET_CDP = "29112"
GASQUET_CDP = "29154"
GAZELLE_CDP = "29252"
GEORGETOWN_CDP = "29350"
GERBER_CDP = "29392"
GEYSERVILLE_CDP = "29420"
GILROY_CITY = "29504"
GLEN_ELLEN_CDP = "30028"
GLENDALE_CITY = "30000"
GLENDORA_CITY = "30014"
GLENNVILLE_CDP = "30126"
GOLD_MOUNTAIN_CDP = "30339"
GOLD_RIVER_CDP = "30345"
GOLDEN_HILLS_CDP = "30282"
GOLETA_CITY = "30378"
GONZALES_CITY = "30392"
GOOD_HOPE_CDP = "30410"
GOODMANVILLE_CDP = "30412"
GOODYEARS_BAR_CDP = "30420"
GOSHEN_CDP = "30476"
GRAEAGLE_CDP = "30560"
GRAND_TERRACE_CITY = "30658"
GRANGEVILLE_CDP = "30686"
GRANITE_BAY_CDP = "30693"
GRANITE_HILLS_CDP = "30703"
GRANITEVILLE_CDP = "30714"
GRASS_VALLEY_CITY = "30798"
GRATON_CDP = "30812"
GRAYSON_CDP = "30882"
GREELEY_HILL_CDP = "30900"
GREEN_ACRES_CDP = "30944"
GREEN_VALLEY_CDP_LOS_ANGELES_COUNTY = "31092"
GREEN_VALLEY_CDP_SOLANO_COUNTY = "31099"
GREENACRES_CDP = "30938"
GREENFIELD_CDP = "30987"
GREENFIELD_CITY = "30994"
GREENHORN_CDP = "31029"
GREENVIEW_CDP = "31134"
GREENVILLE_CDP = "31162"
GRENADA_CDP = "31246"
GRIDLEY_CITY = "31260"
GRIMES_CDP = "31288"
GRIZZLY_FLATS_CDP = "31302"
GROVELAND_CDP = "31372"
GROVER_BEACH_CITY = "31393"
GUADALUPE_CITY = "31414"
GUERNEVILLE_CDP = "31470"
GUINDA_CDP = "31540"
GUSTINE_CITY = "31568"
HACIENDA_HEIGHTS_CDP = "31596"
HALF_MOON_BAY_CITY = "31708"
HAMILTON_BRANCH_CDP = "31883"
HAMILTON_CITY_CDP = "31890"
HANFORD_CITY = "31960"
HAPPY_CAMP_CDP = "32030"
HAPPY_VALLEY_CDP = "32036"
HARBISON_CANYON_CDP = "32044"
HARDWICK_CDP = "32156"
HARMONY_GROVE_CDP = "32212"
HARTLAND_CDP = "32324"
HARTLEY_CDP = "32340"
HASLEY_CANYON_CDP = "32385"
HAT_CREEK_CDP = "32408"
HAWAIIAN_GARDENS_CITY = "32506"
HAWTHORNE_CITY = "32548"
HAYFORK_CDP = "32562"
HAYWARD_CITY = "33000"
HEALDSBURG_CITY = "33056"
HEBER_CDP = "33084"
HEMET_CITY = "33182"
HERALD_CDP = "33294"
HERCULES_CITY = "33308"
HERLONG_CDP = "33336"
HERMOSA_BEACH_CITY = "33364"
HESPERIA_CITY = "33434"
HICKMAN_CDP = "33504"
HIDDEN_HILLS_CITY = "33518"
HIDDEN_MEADOWS_CDP = "33532"
HIDDEN_VALLEY_LAKE_CDP = "33549"
HIGHGROVE_CDP = "33574"
HIGHLAND_CITY = "33588"
HIGHLANDS_CDP = "33632"
HILLCREST_CDP = "33689"
HILLSBOROUGH_TOWN = "33798"
HILMAR_IRWIN_CDP = "33861"
HIOUCHI_CDP = "33935"
HOLLISTER_CITY = "34120"
HOLTVILLE_CITY = "34246"
HOME_GARDEN_CDP = "34281"
HOME_GARDENS_CDP = "34302"
HOMELAND_CDP = "34316"
HOMESTEAD_VALLEY_CDP = "34392"
HOMEWOOD_CANYON_CDP = "34405"
HONCUT_CDP = "34428"
HOOD_CDP = "34484"
HOOPA_CDP = "34540"
HOPLAND_CDP = "34652"
HORNBROOK_CDP = "34694"
HORNITOS_CDP = "34708"
HUGHSON_CITY = "34904"
HUMBOLDT_HILL_CDP = "34928"
HUNTINGTON_BEACH_CITY = "36000"
HUNTINGTON_PARK_CITY = "36056"
HURON_CITY = "36084"
HYAMPOM_CDP = "36098"
HYDESVILLE_CDP = "36126"
HYPERICUM_CDP = "36135"
IDLEWILD_CDP = "36168"
IDYLLWILD_PINE_COVE_CDP = "36203"
IGO_CDP = "36252"
IMPERIAL_BEACH_CITY = "36294"
IMPERIAL_CITY = "36280"
INDEPENDENCE_CDP = "36350"
INDIAN_FALLS_CDP = "36364"
INDIAN_WELLS_CITY = "36434"
INDIANOLA_CDP = "36420"
INDIO_HILLS_CDP = "36452"
INDIO_CITY = "36448"
INDUSTRY_CITY = "36490"
INGLEWOOD_CITY = "36546"
INTERLAKEN_CDP = "36613"
INVERNESS_CDP = "36616"
INYOKERN_CDP = "36658"
IONE_CITY = "36672"
IRON_HORSE_CDP = "36735"
IRVINE_CITY = "36770"
IRWINDALE_CITY = "36826"
ISLA_VISTA_CDP = "36868"
ISLETON_CITY = "36882"
IVANHOE_CDP = "36910"
JACKSON_CITY = "36980"
JACUMBA_CDP = "37022"
JAMESTOWN_CDP = "37106"
JAMUL_CDP = "37120"
JANESVILLE_CDP = "37134"
JENNER_CDP = "37274"
JOHANNESBURG_CDP = "37400"
JOHNSON_PARK_CDP = "37442"
JOHNSTONVILLE_CDP = "37484"
JOHNSVILLE_CDP = "37512"
JONES_VALLEY_CDP = "37533"
JOSHUA_TREE_CDP = "37554"
JOVISTA_CDP = "37568"
JULIAN_CDP = "37582"
JUNCTION_CITY_CDP = "37596"
JUNE_LAKE_CDP = "37624"
JURUPA_VALLEY_CITY = "37692"
KEDDIE_CDP = "37904"
KEELER_CDP = "37918"
KEENE_CDP = "37946"
KELLY_RIDGE_CDP = "38024"
KELSEYVILLE_CDP = "38044"
KENNEDY_CDP = "38065"
KENNEDY_MEADOWS_CDP = "38076"
KENSINGTON_CDP = "38086"
KENTFIELD_CDP = "38114"
KENWOOD_CDP = "38156"
KEPEL_CDP = "38177"
KERMAN_CITY = "38226"
KERNVILLE_CDP = "38310"
KESWICK_CDP = "38352"
KETTLEMAN_CITY_CDP = "38394"
KEYES_CDP = "38422"
KING_CITY_CITY = "38520"
KINGS_BEACH_CDP = "38548"
KINGSBURG_CITY = "38562"
KINGVALE_CDP = "38604"
KIRKWOOD_CDP = "38646"
KLAMATH_CDP = "38702"
KNIGHTS_FERRY_CDP = "38786"
KNIGHTS_LANDING_CDP = "38800"
KNIGHTSEN_CDP = "38772"
LA_CANADA_FLINTRIDGE_CITY = "39003"
LA_CRESCENTA_MONTROSE_CDP = "39045"
LA_CRESTA_CDP = "39052"
LA_GRANGE_CDP = "39164"
LA_HABRA_HEIGHTS_CITY = "39304"
LA_HABRA_CITY = "39290"
LA_HONDA_CDP = "39318"
LA_MESA_CITY = "40004"
LA_MIRADA_CITY = "40032"
LA_PALMA_CITY = "40256"
LA_PORTE_CDP = "40312"
LA_PRESA_CDP = "40326"
LA_PUENTE_CITY = "40340"
LA_QUINTA_CITY = "40354"
LA_RIVIERA_CDP = "40410"
LA_SELVA_BEACH_CDP = "40508"
LA_VERNE_CITY = "40830"
LA_VINA_CDP = "40872"
LADERA_CDP = "39094"
LADERA_HEIGHTS_CDP = "39108"
LADERA_RANCH_CDP = "39114"
LAFAYETTE_CITY = "39122"
LAGUNA_BEACH_CITY = "39178"
LAGUNA_HILLS_CITY = "39220"
LAGUNA_NIGUEL_CITY = "39248"
LAGUNA_WOODS_CITY = "39259"
LAGUNITAS_FOREST_KNOLLS_CDP = "39283"
LAKE_ALMANOR_COUNTRY_CLUB_CDP = "39411"
LAKE_ALMANOR_PENINSULA_CDP = "39420"
LAKE_ALMANOR_WEST_CDP = "39425"
LAKE_ARROWHEAD_CDP = "39444"
LAKE_CALIFORNIA_CDP = "39460"
LAKE_CITY_CDP = "39472"
LAKE_DAVIS_CDP = "39483"
LAKE_DON_PEDRO_CDP = "39484"
LAKE_ELSINORE_CITY = "39486"
LAKE_FOREST_CITY = "39496"
LAKE_HUGHES_CDP = "39556"
LAKE_ISABELLA_CDP = "39570"
LAKE_LOS_ANGELES_CDP = "39612"
LAKE_MATHEWS_CDP = "39645"
LAKE_NACIMIENTO_CDP = "39670"
LAKE_RIVERSIDE_CDP = "39715"
LAKE_SAN_MARCOS_CDP = "39724"
LAKE_SHASTINA_CDP = "39728"
LAKE_SHERWOOD_CDP = "39735"
LAKE_WILDWOOD_CDP = "39885"
LAKE_OF_THE_PINES_CDP = "39690"
LAKE_OF_THE_WOODS_CDP = "39696"
LAKEHEAD_CDP = "39514"
LAKELAND_VILLAGE_CDP = "39598"
LAKEPORT_CITY = "39710"
LAKESIDE_CDP_KERN_COUNTY = "39759"
LAKESIDE_CDP_SAN_DIEGO_COUNTY = "39766"
LAKEVIEW_CDP = "39836"
LAKEWOOD_CITY = "39892"
LAMONT_CDP = "40088"
LANARE_CDP = "40116"
LANCASTER_CITY = "40130"
LARKFIELD_WIKIUP_CDP = "40426"
LARKSPUR_CITY = "40438"
LAS_FLORES_CDP_ORANGE_COUNTY = "40526"
LAS_FLORES_CDP_TEHAMA_COUNTY = "40536"
LAS_LOMAS_CDP = "40592"
LATHROP_CITY = "40704"
LATON_CDP = "40746"
LAWNDALE_CITY = "40886"
LAYTONVILLE_CDP = "40928"
LE_GRAND_CDP = "41040"
LEBEC_CDP = "40956"
LEE_VINING_CDP = "40998"
LEGGETT_CDP = "41026"
LEMON_COVE_CDP = "41110"
LEMON_GROVE_CITY = "41124"
LEMON_HILL_CDP = "41142"
LEMOORE_STATION_CDP = "41166"
LEMOORE_CITY = "41152"
LENNOX_CDP = "41180"
LENWOOD_CDP = "41194"
LEONA_VALLEY_CDP = "41208"
LEWISTON_CDP = "41278"
LEXINGTON_HILLS_CDP = "41282"
LIKELY_CDP = "41390"
LINCOLN_VILLAGE_CDP = "41558"
LINCOLN_CITY = "41474"
LINDA_CDP = "41572"
LINDCOVE_CDP = "41656"
LINDEN_CDP = "41670"
LINDSAY_CITY = "41712"
LINNELL_CAMP_CDP = "41740"
LITCHFIELD_CDP = "41782"
LITTLE_GRASS_VALLEY_CDP = "41789"
LITTLE_RIVER_CDP = "41866"
LITTLE_VALLEY_CDP = "41908"
LITTLEROCK_CDP = "41880"
LIVE_OAK_CDP = "41922"
LIVE_OAK_CITY = "41936"
LIVERMORE_CITY = "41992"
LIVINGSTON_CITY = "42006"
LOCKEFORD_CDP = "42104"
LOCKWOOD_CDP_AMADOR_COUNTY = "42142"
LOCKWOOD_CDP_MONTEREY_COUNTY = "42146"
LODI_CITY = "42202"
LODOGA_CDP = "42230"
LOLETA_CDP = "42328"
LOMA_LINDA_CITY = "42370"
LOMA_MAR_CDP = "42384"
LOMA_RICA_CDP = "42412"
LOMITA_CITY = "42468"
LOMPICO_CDP = "42510"
LOMPOC_CITY = "42524"
LONDON_CDP = "42566"
LONE_PINE_CDP = "42580"
LONG_BARN_CDP = "42622"
LONG_BEACH_CITY = "43000"
LOOKOUT_CDP = "43126"
LOOMIS_TOWN = "43140"
LOS_ALAMITOS_CITY = "43224"
LOS_ALAMOS_CDP = "43252"
LOS_ALTOS_HILLS_TOWN = "43294"
LOS_ALTOS_CITY = "43280"
LOS_ANGELES_CITY = "44000"
LOS_BANOS_CITY = "44028"
LOS_BERROS_CDP = "44042"
LOS_GATOS_TOWN = "44112"
LOS_MOLINOS_CDP = "44140"
LOS_OLIVOS_CDP = "44168"
LOS_OSOS_CDP = "44182"
LOS_RANCHOS_CDP = "44242"
LOST_HILLS_CDP = "44280"
LOWER_LAKE_CDP = "44350"
LOYALTON_CITY = "44364"
LOYOLA_CDP = "44378"
LUCAS_VALLEY_MARINWOOD_CDP = "44399"
LUCERNE_CDP = "44406"
LUCERNE_VALLEY_CDP = "44420"
LYNWOOD_CITY = "44574"
LYTLE_CREEK_CDP = "44644"
MABIE_CDP = "44672"
MACDOEL_CDP = "44812"
MAD_RIVER_CDP = "45092"
MADELINE_CDP = "45008"
MADERA_ACRES_CDP = "45050"
MADERA_RANCHOS_CDP = "45054"
MADERA_CITY = "45022"
MADISON_CDP = "45064"
MAGALIA_CDP = "45120"
MALAGA_CDP = "45232"
MALIBU_CITY = "45246"
MAMMOTH_LAKES_TOWN = "45358"
MANCHESTER_CDP = "45386"
MANHATTAN_BEACH_CITY = "45400"
MANILA_CDP = "45414"
MANTECA_CITY = "45484"
MANTON_CDP = "45512"
MARCH_ARB_CDP = "45680"
MARICOPA_CITY = "45736"
MARIN_CITY_CDP = "45820"
MARINA_CITY = "45778"
MARINA_DEL_REY_CDP = "45806"
MARIPOSA_CDP = "45932"
MARKLEEVILLE_CDP = "45988"
MARTELL_CDP = "46100"
MARTINEZ_CITY = "46114"
MARYSVILLE_CITY = "46170"
MATHENY_CDP = "46223"
MATHER_CDP = "46226"
MAXWELL_CDP = "46338"
MAYFAIR_CDP = "46400"
MAYFLOWER_VILLAGE_CDP = "46436"
MAYWOOD_CITY = "46492"
MCARTHUR_CDP = "44700"
MCCLELLAN_PARK_CDP = "44760"
MCCLENNEY_TRACT_CDP = "44770"
MCCLOUD_CDP = "44784"
MCFARLAND_CITY = "44826"
MCGEE_CREEK_CDP = "44830"
MCKINLEYVILLE_CDP = "44910"
MCKITTRICK_CDP = "44924"
MCSWAIN_CDP = "45006"
MEAD_VALLEY_CDP = "46646"
MEADOW_VALLEY_CDP = "46618"
MEADOW_VISTA_CDP = "46632"
MEADOWBROOK_CDP = "46520"
MECCA_CDP = "46660"
MEINERS_OAKS_CDP = "46702"
MENDOCINO_CDP = "46814"
MENDOTA_CITY = "46828"
MENIFEE_CITY = "46842"
MENLO_PARK_CITY = "46870"
MENTONE_CDP = "46884"
MERCED_CITY = "46898"
MERIDIAN_CDP = "46926"
MESA_CDP = "47013"
MESA_VERDE_CDP = "47066"
MESA_VISTA_CDP = "47086"
METTLER_CDP = "47164"
MEXICAN_COLONY_CDP = "47192"
MEYERS_CDP = "47206"
MI_WUK_VILLAGE_CDP = "48298"
MIDDLETOWN_CDP = "47332"
MIDPINES_CDP = "47374"
MIDWAY_CITY_CDP = "47430"
MILFORD_CDP = "47472"
MILL_VALLEY_CITY = "47710"
MILLBRAE_CITY = "47486"
MILLERTON_CDP = "47592"
MILLVILLE_CDP = "47724"
MILPITAS_CITY = "47766"
MINERAL_CDP = "47794"
MINKLER_CDP = "47822"
MIRA_MONTE_CDP = "48046"
MIRANDA_CDP = "48060"
MISSION_CANYON_CDP = "48147"
MISSION_HILLS_CDP = "48186"
MISSION_VIEJO_CITY = "48256"
MODESTO_CITY = "48354"
MODJESKA_CDP = "48410"
MOHAWK_VISTA_CDP = "48448"
MOJAVE_CDP = "48452"
MOKELUMNE_HILL_CDP = "48480"
MONMOUTH_CDP = "48592"
MONO_CITY_CDP = "48602"
MONO_VISTA_CDP = "48641"
MONROVIA_CITY = "48648"
MONSON_CDP = "48676"
MONTAGUE_CITY = "48690"
MONTALVIN_MANOR_CDP = "48718"
MONTARA_CDP = "48760"
MONTCLAIR_CITY = "48788"
MONTE_RIO_CDP = "48928"
MONTE_SERENO_CITY = "48956"
MONTEBELLO_CITY = "48816"
MONTECITO_CDP = "48844"
MONTEREY_PARK_TRACT_CDP = "48916"
MONTEREY_PARK_CITY = "48914"
MONTEREY_CITY = "48872"
MONTGOMERY_CREEK_CDP = "48998"
MONUMENT_HILLS_CDP = "49045"
MOORPARK_CITY = "49138"
MORADA_CDP = "49180"
MORAGA_TOWN = "49187"
MORENO_VALLEY_CITY = "49270"
MORGAN_HILL_CITY = "49278"
MORONGO_VALLEY_CDP = "49348"
MORRO_BAY_CITY = "49362"
MOSKOWITE_CORNER_CDP = "49432"
MOSS_BEACH_CDP = "49446"
MOSS_LANDING_CDP = "49488"
MOUNT_HEBRON_CDP = "49768"
MOUNT_HERMON_CDP = "49796"
MOUNT_LAGUNA_CDP = "49810"
MOUNT_SHASTA_CITY = "49852"
MOUNTAIN_CENTER_CDP = "49544"
MOUNTAIN_GATE_CDP = "49558"
MOUNTAIN_HOUSE_CDP = "49582"
MOUNTAIN_MEADOWS_CDP = "49592"
MOUNTAIN_MESA_CDP = "49600"
MOUNTAIN_RANCH_CDP = "49628"
MOUNTAIN_VIEW_ACRES_CDP = "49684"
MOUNTAIN_VIEW_CDP = "49651"
MOUNTAIN_VIEW_CITY = "49670"
MT_BULLION_CDP = "49726"
MUIR_BEACH_CDP = "49950"
MURPHYS_CDP = "50034"
MURRIETA_CITY = "50076"
MUSCOY_CDP = "50132"
MYERS_FLAT_CDP = "50146"
MYRTLETOWN_CDP = "50188"
NAPA_CITY = "50258"
NATIONAL_CITY_CITY = "50398"
NEEDLES_CITY = "50734"
NEVADA_CITY_CITY = "50874"
NEW_CUYAMA_CDP = "51028"
NEW_PINE_CREEK_CDP = "51168"
NEWARK_CITY = "50916"
NEWCASTLE_CDP = "51000"
NEWELL_CDP = "51042"
NEWMAN_CITY = "51140"
NEWPORT_BEACH_CITY = "51182"
NICASIO_CDP = "51280"
NICE_CDP = "51294"
NICOLAUS_CDP = "51336"
NILAND_CDP = "51392"
NIPINNAWASEE_CDP = "51470"
NIPOMO_CDP = "51476"
NORCO_CITY = "51560"
NORD_CDP = "51574"
NORRIS_CANYON_CDP = "51622"
NORTH_AUBURN_CDP = "51637"
NORTH_EDWARDS_CDP = "51812"
NORTH_EL_MONTE_CDP = "51820"
NORTH_FAIR_OAKS_CDP = "51840"
NORTH_FORK_CDP = "51868"
NORTH_GATE_CDP = "51890"
NORTH_HIGHLANDS_CDP = "51924"
NORTH_LAKEPORT_CDP = "51990"
NORTH_RICHMOND_CDP = "52162"
NORTH_SAN_JUAN_CDP = "52246"
NORTH_SHORE_CDP = "52302"
NORTH_TUSTIN_CDP = "52379"
NORWALK_CITY = "52526"
NOVATO_CITY = "52582"
NUBIEBER_CDP = "52610"
NUEVO_CDP = "52624"
OAK_GLEN_CDP = "52715"
OAK_HILLS_CDP = "52760"
OAK_PARK_CDP = "53116"
OAK_RUN_CDP = "53140"
OAK_SHORES_CDP = "53160"
OAK_VIEW_CDP = "53182"
OAKDALE_CITY = "52694"
OAKHURST_CDP = "52764"
OAKLAND_CITY = "53000"
OAKLEY_CITY = "53070"
OAKVILLE_CDP = "53196"
OASIS_CDP = "53224"
OCCIDENTAL_CDP = "53266"
OCEANO_CDP = "53294"
OCEANSIDE_CITY = "53322"
OCOTILLO_CDP = "53378"
OILDALE_CDP = "53448"
OJAI_CITY = "53476"
OLANCHA_CDP = "53490"
OLD_FIG_GARDEN_CDP = "53505"
OLD_RIVER_CDP = "53574"
OLD_STATION_CDP = "53602"
OLD_STINE_CDP = "53603"
OLDE_STOCKDALE_CDP = "53503"
OLIVEHURST_CDP = "53714"
ONO_CDP = "53882"
ONTARIO_CITY = "53896"
ONYX_CDP = "53910"
ORANGE_BLOSSOM_CDP = "53987"
ORANGE_COVE_CITY = "54008"
ORANGE_CITY = "53980"
ORANGEVALE_CDP = "54092"
ORCUTT_CDP = "54120"
ORICK_CDP = "54218"
ORINDA_CITY = "54232"
ORLAND_CITY = "54274"
OROSI_CDP = "54372"
OROVILLE_EAST_CDP = "54388"
OROVILLE_CITY = "54386"
OXNARD_CITY = "54652"
PACHECO_CDP = "54764"
PACIFIC_GROVE_CITY = "54848"
PACIFICA_CITY = "54806"
PAJARO_CDP = "55044"
PAJARO_DUNES_CDP = "55048"
PALA_CDP = "55058"
PALERMO_CDP = "55086"
PALM_DESERT_CITY = "55184"
PALM_SPRINGS_CITY = "55254"
PALMDALE_CITY = "55156"
PALO_ALTO_CITY = "55282"
PALO_CEDRO_CDP = "55296"
PALO_VERDE_CDP = "55422"
PALOS_VERDES_ESTATES_CITY = "55380"
PANORAMA_HEIGHTS_CDP = "55506"
PARADISE_CDP = "55528"
PARADISE_PARK_CDP = "55604"
PARADISE_TOWN = "55520"
PARAMOUNT_CITY = "55618"
PARKLAWN_CDP = "55728"
PARKSDALE_CDP = "55751"
PARKWAY_CDP = "55800"
PARKWOOD_CDP = "55842"
PARLIER_CITY = "55856"
PASADENA_CITY = "56000"
PASATIEMPO_CDP = "56028"
PASKENTA_CDP = "56042"
PATTERSON_TRACT_CDP = "56120"
PATTERSON_CITY = "56112"
PATTON_VILLAGE_CDP = "56140"
PAXTON_CDP = "56182"
PAYNES_CREEK_CDP = "56196"
PEARSONVILLE_CDP = "56294"
PENN_VALLEY_CDP = "56518"
PENNGROVE_CDP = "56476"
PENRYN_CDP = "56546"
PEPPERDINE_UNIVERSITY_CDP = "56598"
PERRIS_CITY = "56700"
PESCADERO_CDP = "56756"
PETALUMA_CENTER_CDP = "56786"
PETALUMA_CITY = "56784"
PETERS_CDP = "56798"
PHELAN_CDP = "56826"
PHILLIPSVILLE_CDP = "56854"
PHILO_CDP = "56868"
PHOENIX_LAKE_CDP = "56870"
PICO_RIVERA_CITY = "56924"
PIEDMONT_CITY = "56938"
PIERPOINT_CDP = "57011"
PIKE_CDP = "57036"
PINE_CANYON_CDP = "57070"
PINE_FLAT_CDP = "57134"
PINE_GROVE_CDP = "57148"
PINE_HILLS_CDP = "57204"
PINE_MOUNTAIN_CLUB_CDP = "57240"
PINE_MOUNTAIN_LAKE_CDP = "57244"
PINE_VALLEY_CDP = "57260"
PINOLE_CITY = "57288"
PIONEER_CDP = "57330"
PIRU_CDP = "57372"
PISMO_BEACH_CITY = "57414"
PITTSBURG_CITY = "57456"
PIXLEY_CDP = "57512"
PINON_HILLS_CDP = "57302"
PLACENTIA_CITY = "57526"
PLACERVILLE_CITY = "57540"
PLAINVIEW_CDP = "57568"
PLANADA_CDP = "57582"
PLATINA_CDP = "57666"
PLEASANT_HILL_CITY = "57764"
PLEASANTON_CITY = "57792"
PLEASURE_POINT_CDP = "57825"
PLUMAS_EUREKA_CDP = "57828"
PLUMAS_LAKE_CDP = "57829"
PLYMOUTH_CITY = "57834"
POINT_ARENA_CITY = "57876"
POINT_REYES_STATION_CDP = "57960"
POLLOCK_PINES_CDP = "58030"
POMONA_CITY = "58072"
PONDEROSA_CDP = "58134"
POPLAR_COTTON_CENTER_CDP = "58191"
PORT_COSTA_CDP = "58226"
PORT_HUENEME_CITY = "58296"
PORTERVILLE_CITY = "58240"
PORTOLA_VALLEY_TOWN = "58380"
PORTOLA_CITY = "58352"
POSEY_CDP = "58422"
POSO_PARK_CDP = "58436"
POST_MOUNTAIN_CDP = "58456"
POTOMAC_PARK_CDP = "58471"
POTRERO_CDP = "58478"
POTTER_VALLEY_CDP = "58506"
POWAY_CITY = "58520"
PRATTVILLE_CDP = "58618"
PRINCETON_CDP = "58758"
PROBERTA_CDP = "58814"
PRUNEDALE_CDP = "58870"
PUMPKIN_CENTER_CDP = "58940"
QUARTZ_HILL_CDP = "59052"
QUINCY_CDP = "59080"
RACKERBY_CDP = "59115"
RAIL_ROAD_FLAT_CDP = "59220"
RAINBOW_CDP = "59248"
RAISIN_CITY_CDP = "59290"
RAMONA_CDP = "59346"
RANCHO_CALAVERAS_CDP = "59426"
RANCHO_CORDOVA_CITY = "59444"
RANCHO_CUCAMONGA_CITY = "59451"
RANCHO_MIRAGE_CITY = "59500"
RANCHO_MISSION_VIEJO_CDP = "59503"
RANCHO_MURIETA_CDP = "59506"
RANCHO_PALOS_VERDES_CITY = "59514"
RANCHO_SAN_DIEGO_CDP = "59550"
RANCHO_SANTA_FE_CDP = "59584"
RANCHO_SANTA_MARGARITA_CITY = "59587"
RANCHO_TEHAMA_RESERVE_CDP = "59604"
RANDSBURG_CDP = "59668"
RED_BLUFF_CITY = "59892"
RED_CORRAL_CDP = "59896"
REDCREST_CDP = "59906"
REDDING_CITY = "59920"
REDLANDS_CITY = "59962"
REDONDO_BEACH_CITY = "60018"
REDWAY_CDP = "60088"
REDWOOD_CITY_CITY = "60102"
REDWOOD_VALLEY_CDP = "60214"
REEDLEY_CITY = "60242"
RELIEZ_VALLEY_CDP = "60279"
REXLAND_ACRES_CDP = "60370"
RIALTO_CITY = "60466"
RICHFIELD_CDP = "60592"
RICHGROVE_CDP = "60606"
RICHMOND_CITY = "60620"
RICHVALE_CDP = "60662"
RIDGECREST_HEIGHTS_CDP = "60705"
RIDGECREST_CITY = "60704"
RIDGEMARK_CDP = "60706"
RIO_DELL_CITY = "60900"
RIO_LINDA_CDP = "60942"
RIO_OSO_CDP = "60970"
RIO_VISTA_CITY = "60984"
RIO_DEL_MAR_CDP = "60928"
RIPLEY_CDP = "61012"
RIPON_CITY = "61026"
RIVER_PINES_CDP = "61124"
RIVERBANK_CITY = "61068"
RIVERDALE_CDP = "61096"
RIVERDALE_PARK_CDP = "61106"
RIVERGROVE_CDP = "61108"
RIVERSIDE_CITY = "62000"
ROBBINS_CDP = "62168"
ROBINSON_MILL_CDP = "62200"
ROCKLIN_CITY = "62364"
RODEO_CDP = "62490"
RODRIGUEZ_CAMP_CDP = "62496"
ROHNERT_PARK_CITY = "62546"
ROLLING_HILLS_CDP = "62625"
ROLLING_HILLS_ESTATES_CITY = "62644"
ROLLING_HILLS_CITY = "62602"
ROLLINGWOOD_CDP = "62700"
ROMOLAND_CDP = "62756"
ROSAMOND_CDP = "62826"
ROSE_HILLS_CDP = "62860"
ROSEDALE_CDP = "62854"
ROSEMEAD_CITY = "62896"
ROSEMONT_CDP = "62910"
ROSEVILLE_CITY = "62938"
ROSS_TOWN = "62980"
ROSSMOOR_CDP = "63050"
ROUGH_AND_READY_CDP = "63106"
ROUND_MOUNTAIN_CDP = "63134"
ROUND_VALLEY_CDP = "63148"
ROUSE_CDP = "63168"
ROWLAND_HEIGHTS_CDP = "63218"
RUMSEY_CDP = "63302"
RUNNING_SPRINGS_CDP = "63316"
RUTH_CDP = "63386"
RUTHERFORD_CDP = "63400"
SACRAMENTO_CITY = "64000"
SAGE_CDP = "64056"
SALIDA_CDP = "64210"
SALINAS_CITY = "64224"
SALMON_CREEK_CDP = "64252"
SALTON_CITY_CDP = "64294"
SALTON_SEA_BEACH_CDP = "64308"
SALYER_CDP = "64378"
SAMOA_CDP = "64392"
SAN_ANDREAS_CDP = "64420"
SAN_ANSELMO_TOWN = "64434"
SAN_ANTONIO_HEIGHTS_CDP = "64462"
SAN_ARDO_CDP = "64476"
SAN_BERNARDINO_CITY = "65000"
SAN_BRUNO_CITY = "65028"
SAN_BUENAVENTURA_VENTURA_CITY = "65042"
SAN_CARLOS_CITY = "65070"
SAN_CLEMENTE_CITY = "65084"
SAN_DIEGO_COUNTRY_ESTATES_CDP = "66004"
SAN_DIEGO_CITY = "66000"
SAN_DIMAS_CITY = "66070"
SAN_FERNANDO_CITY = "66140"
SAN_FRANCISCO_CITY = "67000"
SAN_GABRIEL_CITY = "67042"
SAN_GERONIMO_CDP = "67070"
SAN_JACINTO_CITY = "67112"
SAN_JOAQUIN_CITY = "67126"
SAN_JOSE_CITY = "68000"
SAN_JUAN_BAUTISTA_CITY = "68014"
SAN_JUAN_CAPISTRANO_CITY = "68028"
SAN_LEANDRO_CITY = "68084"
SAN_LORENZO_CDP = "68112"
SAN_LUCAS_CDP = "68140"
SAN_LUIS_OBISPO_CITY = "68154"
SAN_MARCOS_CITY = "68196"
SAN_MARINO_CITY = "68224"
SAN_MARTIN_CDP = "68238"
SAN_MATEO_CITY = "68252"
SAN_MIGUEL_CDP_CONTRA_COSTA_COUNTY = "68263"
SAN_MIGUEL_CDP_SAN_LUIS_OBISPO_COUNTY = "68266"
SAN_PABLO_CITY = "68294"
SAN_PASQUAL_CDP = "68308"
SAN_RAFAEL_CITY = "68364"
SAN_RAMON_CITY = "68378"
SAN_SIMEON_CDP = "68434"
SAND_CITY_CITY = "65112"
SANGER_CITY = "67056"
SANTA_ANA_CITY = "69000"
SANTA_BARBARA_CITY = "69070"
SANTA_CLARA_CITY = "69084"
SANTA_CLARITA_CITY = "69088"
SANTA_CRUZ_CITY = "69112"
SANTA_FE_SPRINGS_CITY = "69154"
SANTA_MARGARITA_CDP = "69182"
SANTA_MARIA_CITY = "69196"
SANTA_MONICA_CITY = "70000"
SANTA_NELLA_CDP = "70028"
SANTA_PAULA_CITY = "70042"
SANTA_ROSA_VALLEY_CDP = "70130"
SANTA_ROSA_CITY = "70098"
SANTA_SUSANA_CDP = "70140"
SANTA_VENETIA_CDP = "70154"
SANTA_YNEZ_CDP = "70182"
SANTEE_CITY = "70224"
SARANAP_CDP = "70266"
SARATOGA_CITY = "70280"
SATICOY_CDP = "70322"
SATTLEY_CDP = "70336"
SAUSALITO_CITY = "70364"
SCOTIA_CDP = "70518"
SCOTTS_VALLEY_CITY = "70588"
SEA_RANCH_CDP = "70712"
SEACLIFF_CDP = "70644"
SEAL_BEACH_CITY = "70686"
SEARLES_VALLEY_CDP = "70728"
SEASIDE_CITY = "70742"
SEBASTOPOL_CITY = "70770"
SEELEY_CDP = "70798"
SELMA_CITY = "70882"
SEQUOIA_CREST_CDP = "70966"
SERENO_DEL_MAR_CDP = "71000"
SEVILLE_CDP = "71078"
SHAFTER_CITY = "71106"
SHANDON_CDP = "71134"
SHASTA_CDP = "71218"
SHASTA_LAKE_CITY = "71225"
SHAVER_LAKE_CDP = "71246"
SHELL_RIDGE_CDP = "71362"
SHELTER_COVE_CDP = "71372"
SHERIDAN_CDP = "71414"
SHINGLE_SPRINGS_CDP = "71554"
SHINGLETOWN_CDP = "71568"
SHOSHONE_CDP = "71680"
SIERRA_BROOKS_CDP = "71774"
SIERRA_CITY_CDP = "71778"
SIERRA_MADRE_CITY = "71806"
SIERRA_VILLAGE_CDP = "71834"
SIERRAVILLE_CDP = "71848"
SIGNAL_HILL_CITY = "71876"
SILVER_CITY_CDP = "71932"
SILVER_LAKES_CDP = "71964"
SILVERADO_CDP = "71918"
SILVERADO_RESORT_CDP = "71927"
SIMI_VALLEY_CITY = "72016"
SISQUOC_CDP = "72086"
SKY_VALLEY_CDP = "72156"
SLEEPY_HOLLOW_CDP = "72184"
SMARTSVILLE_CDP = "72282"
SMITH_CORNER_CDP = "72338"
SMITH_RIVER_CDP = "72380"
SNELLING_CDP = "72408"
SODA_BAY_CDP = "72478"
SODA_SPRINGS_CDP = "72492"
SOLANA_BEACH_CITY = "72506"
SOLEDAD_CITY = "72520"
SOLVANG_CITY = "72576"
SOMIS_CDP = "72632"
SONOMA_STATE_UNIVERSITY_CDP = "72654"
SONOMA_CITY = "72646"
SONORA_CITY = "72674"
SOQUEL_CDP = "72688"
SOULSBYVILLE_CDP = "72772"
SOUTH_DOS_PALOS_CDP = "72954"
SOUTH_EL_MONTE_CITY = "72996"
SOUTH_GATE_CITY = "73080"
SOUTH_LAKE_TAHOE_CITY = "73108"
SOUTH_MONROVIA_ISLAND_CDP = "73167"
SOUTH_OROVILLE_CDP = "73178"
SOUTH_PASADENA_CITY = "73220"
SOUTH_SAN_FRANCISCO_CITY = "73262"
SOUTH_SAN_GABRIEL_CDP = "73276"
SOUTH_SAN_JOSE_HILLS_CDP = "73290"
SOUTH_TAFT_CDP = "73388"
SOUTH_WHITTIER_CDP = "73430"
SPAULDING_CDP = "73554"
SPRECKELS_CDP = "73612"
SPRING_GARDEN_CDP = "73654"
SPRING_VALLEY_CDP_LAKE_COUNTY = "73690"
SPRING_VALLEY_CDP_SAN_DIEGO_COUNTY = "73696"
SPRING_VALLEY_LAKE_CDP = "73700"
SPRINGVILLE_CDP = "73710"
SQUAW_VALLEY_CDP = "73794"
SQUIRREL_MOUNTAIN_VALLEY_CDP = "73815"
ST_HELENA_CITY = "64140"
STALLION_SPRINGS_CDP = "73868"
STANFORD_CDP = "73906"
STANTON_CITY = "73962"
STEBBINS_CDP = "74021"
STEVENSON_RANCH_CDP = "74130"
STEVINSON_CDP = "74144"
STINSON_BEACH_CDP = "74172"
STIRLING_CITY_CDP = "74186"
STOCKTON_CITY = "75000"
STONES_LANDING_CDP = "75122"
STONYFORD_CDP = "75154"
STRATFORD_CDP = "75252"
STRATHMORE_CDP = "75280"
STRAWBERRY_CDP_MARIN_COUNTY = "75315"
STRAWBERRY_CDP_TUOLUMNE_COUNTY = "75322"
SUGARLOAF_SAW_MILL_CDP = "75592"
SUGARLOAF_VILLAGE_CDP = "75596"
SUISUN_CITY_CITY = "75630"
SULTANA_CDP = "75672"
SUMMERLAND_CDP = "75714"
SUN_VILLAGE_CDP = "77308"
SUNNY_SLOPES_CDP = "76040"
SUNNYSIDE_CDP = "75994"
SUNNYSIDE_TAHOE_CITY_CDP = "76015"
SUNNYVALE_CITY = "77000"
SUNOL_CDP = "77042"
SUSANVILLE_CITY = "77364"
SUTTER_CDP = "77378"
SUTTER_CREEK_CITY = "77392"
SWALL_MEADOWS_CDP = "77430"
TAFT_HEIGHTS_CDP = "77588"
TAFT_MOSSWOOD_CDP = "77595"
TAFT_CITY = "77574"
TAHOE_VISTA_CDP = "77700"
TAHOMA_CDP = "77728"
TALMAGE_CDP = "77784"
TAMALPAIS_HOMESTEAD_VALLEY_CDP = "77805"
TANCRED_CDP = "77860"
TARA_HILLS_CDP = "77924"
TARINA_CDP = "77934"
TARPEY_VILLAGE_CDP = "77960"
TAYLORSVILLE_CDP = "78008"
TECOPA_CDP = "78050"
TEHACHAPI_CITY = "78092"
TEHAMA_CITY = "78106"
TEMECULA_CITY = "78120"
TEMELEC_CDP = "78126"
TEMESCAL_VALLEY_CDP = "78138"
TEMPLE_CITY_CITY = "78148"
TEMPLETON_CDP = "78162"
TENNANT_CDP = "78176"
TERMINOUS_CDP = "78232"
TERRA_BELLA_CDP = "78288"
TEVISTON_CDP = "78336"
THERMAL_CDP = "78456"
THERMALITO_CDP = "78470"
THORNTON_CDP = "78568"
THOUSAND_OAKS_CITY = "78582"
THOUSAND_PALMS_CDP = "78596"
THREE_RIVERS_CDP = "78638"
THREE_ROCKS_CDP = "78652"
TIBURON_TOWN = "78666"
TIMBER_COVE_CDP = "78715"
TIPTON_CDP = "78750"
TOBIN_CDP = "78792"
TOMALES_CDP = "78890"
TONYVILLE_CDP = "78932"
TOOLEVILLE_CDP = "78949"
TOPANGA_CDP = "78960"
TOPAZ_CDP = "79030"
TORO_CANYON_CDP = "79529"
TORRANCE_CITY = "80000"
TRABUCO_CANYON_CDP = "80210"
TRACY_CITY = "80238"
TRANQUILLITY_CDP = "80266"
TRAVER_CDP = "80280"
TRES_PINOS_CDP = "80364"
TRINIDAD_CITY = "80448"
TRINITY_CENTER_CDP = "80476"
TRINITY_VILLAGE_CDP = "80483"
TRONA_CDP = "80515"
TROWBRIDGE_CDP = "80560"
TRUCKEE_TOWN = "80588"
TULARE_CITY = "80644"
TULELAKE_CITY = "80686"
TUOLUMNE_CITY_CDP = "80763"
TUPMAN_CDP = "80784"
TURLOCK_CITY = "80812"
TUSTIN_CITY = "80854"
TUTTLE_CDP = "80882"
TUTTLETOWN_CDP = "80896"
TWAIN_CDP = "80952"
TWAIN_HARTE_CDP = "80966"
TWENTYNINE_PALMS_CITY = "80994"
TWIN_LAKES_CDP_MONO_COUNTY = "81048"
TWIN_LAKES_CDP_SANTA_CRUZ_COUNTY = "81050"
UKIAH_CITY = "81134"
UNION_CITY_CITY = "81204"
UNIVERSITY_OF_CALIFORNIA_DAVIS_CDP = "81302"
UNIVERSITY_OF_CALIFORNIA_MERCED_CDP = "81312"
UNIVERSITY_OF_CALIFORNIA_SANTA_BARBARA_CDP = "81316"
UPLAND_CITY = "81344"
UPPER_LAKE_CDP = "81358"
VACAVILLE_CITY = "81554"
VAL_VERDE_CDP = "81967"
VALINDA_CDP = "81638"
VALLE_VISTA_CDP = "81708"
VALLECITO_CDP = "81652"
VALLEJO_CITY = "81666"
VALLEY_ACRES_CDP = "81722"
VALLEY_CENTER_CDP = "81736"
VALLEY_FORD_CDP = "81778"
VALLEY_HOME_CDP = "81792"
VALLEY_RANCH_CDP = "81869"
VALLEY_SPRINGS_CDP = "81890"
VALLEY_WELLS_CDP = "81925"
VANDENBERG_AFB_CDP = "82072"
VANDENBERG_VILLAGE_CDP = "82086"
VERDI_CDP = "82334"
VERNON_CITY = "82422"
VICTOR_CDP = "82562"
VICTORVILLE_CITY = "82590"
VIEW_PARK_WINDSOR_HILLS_CDP = "82667"
VILLA_PARK_CITY = "82744"
VINA_CDP = "82786"
VINCENT_CDP = "82815"
VINE_HILL_CDP = "82842"
VINEYARD_CDP = "82852"
VIRGINIA_LAKES_CDP = "82929"
VISALIA_CITY = "82954"
VISTA_SANTA_ROSA_CDP = "83085"
VISTA_CITY = "82996"
VOLCANO_CDP = "83094"
VOLTA_CDP = "83108"
WALKER_CDP = "83262"
WALLACE_CDP = "83304"
WALNUT_CREEK_CITY = "83346"
WALNUT_GROVE_CDP = "83374"
WALNUT_PARK_CDP = "83402"
WALNUT_CITY = "83332"
WARM_SPRINGS_CDP = "83460"
WARNER_VALLEY_CDP = "83494"
WASCO_CITY = "83542"
WASHINGTON_CDP = "83570"
WATERFORD_CITY = "83612"
WATERLOO_CDP = "83626"
WATSONVILLE_CITY = "83668"
WAUKENA_CDP = "83724"
WAUTEC_CDP = "83730"
WAWONA_CDP = "83766"
WEAVERVILLE_CDP = "83794"
WEED_CITY = "83850"
WEEDPATCH_CDP = "83863"
WEITCHPEC_CDP = "83906"
WELDON_CDP = "83948"
WEOTT_CDP = "84004"
WEST_ATHENS_CDP = "84116"
WEST_BISHOP_CDP = "84120"
WEST_CARSON_CDP = "84144"
WEST_COVINA_CITY = "84200"
WEST_GOSHEN_CDP = "84345"
WEST_HOLLYWOOD_CITY = "84410"
WEST_MENLO_PARK_CDP = "84536"
WEST_MODESTO_CDP = "84578"
WEST_PARK_CDP = "84680"
WEST_POINT_CDP = "84732"
WEST_PUENTE_VALLEY_CDP = "84774"
WEST_RANCHO_DOMINGUEZ_CDP = "84780"
WEST_SACRAMENTO_CITY = "84816"
WEST_WHITTIER_LOS_NIETOS_CDP = "84921"
WESTHAVEN_MOONSTONE_CDP = "84385"
WESTLAKE_VILLAGE_CITY = "84438"
WESTLEY_CDP = "84480"
WESTMINSTER_CITY = "84550"
WESTMONT_CDP = "84592"
WESTMORLAND_CITY = "84606"
WESTSIDE_CDP = "84863"
WESTWOOD_CDP = "84928"
WHEATLAND_CITY = "85012"
WHITEHAWK_CDP = "85086"
WHITEWATER_CDP = "85208"
WHITLEY_GARDENS_CDP = "85222"
WHITMORE_CDP = "85250"
WHITTIER_CITY = "85292"
WILDOMAR_CITY = "85446"
WILKERSON_CDP = "85551"
WILLIAMS_CANYON_CDP = "85587"
WILLIAMS_CITY = "85586"
WILLITS_CITY = "85600"
WILLOW_CREEK_CDP = "85642"
WILLOWBROOK_CDP = "85614"
WILLOWS_CITY = "85684"
WILSONIA_CDP = "85866"
WILTON_CDP = "85880"
WINCHESTER_CDP = "85894"
WINDSOR_TOWN = "85922"
WINTER_GARDENS_CDP = "85992"
WINTERHAVEN_CDP = "86020"
WINTERS_CITY = "86034"
WINTON_CDP = "86076"
WOFFORD_HEIGHTS_CDP = "86174"
WOODACRE_CDP = "86216"
WOODBRIDGE_CDP = "86230"
WOODCREST_CDP = "86244"
WOODLAKE_CITY = "86300"
WOODLAND_CITY = "86328"
WOODLANDS_CDP = "86380"
WOODSIDE_TOWN = "86440"
WOODVILLE_CDP = "86482"
WOODVILLE_FARM_LABOR_CAMP_CDP = "86489"
WOODY_CDP = "86496"
WRIGHTWOOD_CDP = "86594"
YANKEE_HILL_CDP = "86678"
YERMO_CDP = "86720"
YETTEM_CDP = "86734"
YOLO_CDP = "86804"
YORBA_LINDA_CITY = "86832"
YOSEMITE_LAKES_CDP = "86878"
YOSEMITE_VALLEY_CDP = "86912"
YOSEMITE_WEST_CDP = "86916"
YOUNTVILLE_CITY = "86930"
YREKA_CITY = "86944"
YUBA_CITY_CITY = "86972"
YUCAIPA_CITY = "87042"
YUCCA_VALLEY_TOWN = "87056"
ZAYANTE_CDP = "87090"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in North Dakota."""


ABERCROMBIE_CITY = "00100"
ADAMS_CITY = "00340"
ALAMO_CITY = "00940"
ALEXANDER_CITY = "01180"
ALICE_CITY = "01420"
ALMONT_CITY = "01700"
ALSEN_CITY = "01740"
AMBROSE_CITY = "01860"
AMENIA_CITY = "01940"
AMIDON_CITY = "02060"
ANAMOOSE_CITY = "02220"
ANETA_CITY = "02380"
ANTLER_CITY = "02660"
APPLE_VALLEY_CDP = "02820"
ARDOCH_CITY = "02860"
ARGUSVILLE_CITY = "03020"
ARNEGARD_CITY = "03220"
ARTHUR_CITY = "03300"
ASHLEY_CITY = "03540"
AUBURN_CDP = "03740"
AYR_CITY = "04020"
BALFOUR_CITY = "04460"
BALTA_CITY = "04580"
BANTRY_CDP = "04740"
BARNEY_CITY = "04940"
BARTON_CDP = "05220"
BATHGATE_CITY = "05260"
BEACH_CITY = "05420"
BELCOURT_CDP = "05740"
BELFIELD_CITY = "05820"
BENEDICT_CITY = "05980"
BERGEN_CITY = "06180"
BERLIN_CITY = "06300"
BERTHOLD_CITY = "06460"
BEULAH_CITY = "06660"
BINFORD_CITY = "07020"
BISBEE_CITY = "07180"
BISMARCK_CITY = "07200"
BLACKTAIL_CDP = "07456"
BLANCHARD_CDP = "07620"
BOTTINEAU_CITY = "08460"
BOWBELLS_CITY = "08500"
BOWDON_CITY = "08580"
BOWMAN_CITY = "08700"
BRADDOCK_CITY = "08900"
BRIARWOOD_CITY = "09320"
BRINSMADE_CITY = "09460"
BROCKET_CITY = "09700"
BROOKTREE_PARK_CDP = "09830"
BUCHANAN_CITY = "10060"
BUCYRUS_CITY = "10300"
BUFFALO_CITY = "10420"
BURLINGTON_CITY = "10940"
BUTTE_CITY = "11180"
BUXTON_CITY = "11340"
CALEDONIA_CDP = "11500"
CALIO_CITY = "11580"
CALVIN_CITY = "11700"
CANDO_CITY = "11860"
CANNON_BALL_CDP = "12020"
CANTON_CITY_HENSEL_CITY = "12060"
CARPIO_CITY = "12260"
CARRINGTON_CITY = "12340"
CARSON_CITY = "12460"
CASSELTON_CITY = "12700"
CATHAY_CITY = "12820"
CAVALIER_CITY = "12940"
CAYUGA_CITY = "13020"
CENTER_CITY = "13180"
CHRISTINE_CITY = "14100"
CHURCHS_FERRY_CITY = "14140"
CLEVELAND_CITY = "14660"
CLIFFORD_CITY = "14740"
COGSWELL_CITY = "15100"
COLEHARBOR_CITY = "15140"
COLFAX_CITY = "15180"
COLUMBUS_CITY = "15460"
CONWAY_CITY = "15820"
COOPERSTOWN_CITY = "15900"
COURTENAY_CITY = "16380"
CRARY_CITY = "16580"
CROSBY_CITY = "16940"
CRYSTAL_CITY = "17060"
DAHLEN_CDP = "17620"
DAVENPORT_CITY = "18180"
DAWSON_CITY = "18260"
DAZEY_CITY = "18340"
DE_LAMERE_CDP = "18820"
DEERING_CITY = "18620"
DENHOFF_CDP = "19060"
DES_LACS_CITY = "19300"
DEVILS_LAKE_CITY = "19420"
DICKEY_CITY = "19580"
DICKINSON_CITY = "19620"
DODGE_CITY = "19820"
DONNYBROOK_CITY = "19900"
DOUGLAS_CITY = "20020"
DRAKE_CITY = "20300"
DRAYTON_CITY = "20340"
DRISCOLL_CDP = "20500"
DUNN_CENTER_CITY = "20940"
DUNSEITH_CITY = "21020"
DWIGHT_CITY = "21220"
EAST_DUNSEITH_CDP = "21520"
EAST_FAIRVIEW_CDP = "21580"
EDGELEY_CITY = "22140"
EDINBURG_CITY = "22260"
EDMORE_CITY = "22340"
EGELAND_CITY = "22540"
ELGIN_CITY = "23020"
ELLENDALE_CITY = "23220"
ELLIOTT_CITY = "23340"
EMBDEN_CDP = "24020"
EMERADO_CITY = "24060"
ENDERLIN_CITY = "24260"
ENGLEVALE_CDP = "24380"
EPPING_CITY = "24540"
ERIE_CDP = "24620"
ESMOND_CITY = "24780"
FAIRDALE_CITY = "25180"
FAIRMOUNT_CITY = "25300"
FARGO_CITY = "25700"
FESSENDEN_CITY = "26180"
FINGAL_CITY = "26380"
FINLEY_CITY = "26420"
FLASHER_CITY = "26660"
FLAXTON_CITY = "26700"
FORBES_CITY = "26980"
FORDVILLE_CITY = "27060"
FOREST_RIVER_CITY = "27100"
FORMAN_CITY = "27260"
FORT_RANSOM_CITY = "27580"
FORT_TOTTEN_CDP = "27700"
FORT_YATES_CITY = "27860"
FORTUNA_CITY = "27820"
FOUR_BEARS_VILLAGE_CDP = "27950"
FOXHOLM_CDP = "27980"
FREDONIA_CITY = "28380"
FRONTIER_CITY = "28720"
FULLERTON_CITY = "28780"
GACKLE_CITY = "28860"
GALESBURG_CITY = "28980"
GARDENA_CITY = "29180"
GARDNER_CITY = "29220"
GARRISON_CITY = "29460"
GASCOYNE_CITY = "29540"
GILBY_CITY = "30180"
GLADSTONE_CITY = "30460"
GLEN_ULLIN_CITY = "30860"
GLENBURN_CITY = "30580"
GLENFIELD_CITY = "30660"
GOLDEN_VALLEY_CITY = "31180"
GOLVA_CITY = "31420"
GOODRICH_CITY = "31500"
GRACE_CITY_CITY = "31740"
GRAFTON_CITY = "31820"
GRAND_FORKS_AFB_CDP = "32140"
GRAND_FORKS_CITY = "32060"
GRANDIN_CITY = "32300"
GRANO_CITY = "32580"
GRANVILLE_CITY = "32660"
GREAT_BEND_CITY = "32900"
GREEN_ACRES_CDP = "33050"
GRENORA_CITY = "33500"
GWINNER_CITY = "34020"
HAGUE_CITY = "34180"
HALLIDAY_CITY = "34340"
HAMBERG_CITY = "34460"
HAMILTON_CITY = "34620"
HAMPDEN_CITY = "34860"
HANKINSON_CITY = "34900"
HANNAFORD_CITY = "35020"
HANNAH_CITY = "35060"
HANSBORO_CITY = "35140"
HARMON_CDP = "35500"
HARVEY_CITY = "35900"
HARWOOD_CITY = "35940"
HATTON_CITY = "36100"
HAVANA_CITY = "36140"
HAYNES_CITY = "36540"
HAZELTON_CITY = "36700"
HAZEN_CITY = "36780"
HEBRON_CITY = "36860"
HEIL_CDP = "36980"
HEIMDAL_CDP = "37020"
HETTINGER_CITY = "37700"
HILLSBORO_CITY = "38100"
HOOPLE_CITY = "38780"
HOPE_CITY = "38860"
HORACE_CITY = "38900"
HUNTER_CITY = "39460"
HURDSFIELD_CITY = "39580"
INKSTER_CITY = "39980"
JAMESTOWN_CITY = "40580"
JESSIE_CDP = "40740"
JUD_CITY = "41180"
KARLSRUHE_CITY = "41380"
KATHRYN_CITY = "41500"
KENMARE_CITY = "42020"
KENSAL_CITY = "42180"
KIEF_CITY = "42660"
KILLDEER_CITY = "42700"
KINDRED_CITY = "42780"
KNOX_CITY = "43260"
KRAMER_CITY = "43500"
KULM_CITY = "43580"
LAMOURE_CITY = "44540"
LAKOTA_CITY = "44300"
LANDA_CITY = "44700"
LANGDON_CITY = "44780"
LANKIN_CITY = "44860"
LANSFORD_CITY = "44900"
LARIMORE_CITY = "45020"
LARSON_CDP = "45220"
LAWTON_CITY = "45300"
LEAL_CITY = "45460"
LEEDS_CITY = "45580"
LEHR_CITY = "45740"
LEITH_CITY = "45860"
LEONARD_CITY = "45980"
LIDGERWOOD_CITY = "46460"
LIGNITE_CITY = "46540"
LINCOLN_CITY = "46640"
LINTON_CITY = "46980"
LISBON_CITY = "47100"
LITCHVILLE_CITY = "47140"
LOGAN_CDP = "47540"
LOMA_CITY = "47660"
LONG_CREEK_CDP = "47796"
LORAINE_CITY = "48020"
LUDDEN_CITY = "48460"
LUVERNE_CITY = "48580"
MADDOCK_CITY = "49620"
MAKOTI_CITY = "49820"
MANDAN_CITY = "49900"
MANDAREE_CDP = "49980"
MANNING_CDP = "50220"
MANTADOR_CITY = "50380"
MANVEL_CITY = "50420"
MAPLETON_CITY = "50580"
MARION_CITY = "50780"
MARMARTH_CITY = "50860"
MARTIN_CITY = "51060"
MAX_CITY = "51380"
MAXBASS_CITY = "51420"
MAYVILLE_CITY = "51500"
MCCLUSKY_CITY = "49020"
MCGREGOR_CDP = "49220"
MCHENRY_CITY = "49260"
MCLEOD_CDP = "49540"
MCVILLE_CITY = "49580"
MEDINA_CITY = "51860"
MEDORA_CITY = "51900"
MENOKEN_CDP = "52180"
MERCER_CITY = "52340"
MICHIGAN_CITY_CITY = "52740"
MILNOR_CITY = "52940"
MILTON_CITY = "53020"
MINNEWAUKAN_CITY = "53220"
MINOT_AFB_CDP = "53420"
MINOT_CITY = "53380"
MINTO_CITY = "53540"
MOHALL_CITY = "53780"
MONANGO_CITY = "53820"
MONTPELIER_CITY = "53980"
MOORETON_CITY = "54220"
MOTT_CITY = "54620"
MOUNTAIN_CITY = "54740"
MUNICH_CITY = "55020"
MYLO_CITY = "55220"
NAPOLEON_CITY = "55420"
NASH_CDP = "55500"
NECHE_CITY = "55620"
NEKOMA_CITY = "55740"
NEW_ENGLAND_CITY = "56180"
NEW_LEIPZIG_CITY = "56420"
NEW_ROCKFORD_CITY = "56620"
NEW_SALEM_CITY = "56700"
NEW_TOWN_CITY = "56740"
NEWBURG_CITY = "56020"
NIAGARA_CITY = "56780"
NOME_CITY = "57180"
NOONAN_CITY = "57220"
NORTH_RIVER_CITY = "58120"
NORTHWOOD_CITY = "58300"
OAKES_CITY = "58740"
OBERON_CITY = "59020"
ORISKA_CITY = "59660"
ORRIN_CDP = "59820"
OSNABROCK_CITY = "60100"
OVERLY_CITY = "60380"
OXBOW_CITY = "60480"
PAGE_CITY = "60500"
PALERMO_CITY = "60620"
PARK_RIVER_CITY = "60900"
PARSHALL_CITY = "60940"
PEKIN_CITY = "61460"
PEMBINA_CITY = "61580"
PERTH_CITY = "61780"
PETERSBURG_CITY = "61860"
PETTIBONE_CITY = "62060"
PICK_CITY_CITY = "62260"
PILLSBURY_CITY = "62540"
PINGREE_CITY = "62620"
PISEK_CITY = "62780"
PLAZA_CITY = "62980"
PORCUPINE_CDP = "63700"
PORTAL_CITY = "63740"
PORTLAND_CITY = "63900"
POWERS_LAKE_CITY = "64140"
PRAIRIE_ROSE_CITY = "64320"
RALEIGH_CDP = "65100"
RAY_CITY = "65580"
REEDER_CITY = "65900"
REGAN_CITY = "65980"
REGENT_CITY = "66020"
REILES_ACRES_CITY = "66040"
REYNOLDS_CITY = "66260"
RHAME_CITY = "66300"
RICHARDTON_CITY = "66500"
RIVERDALE_CITY = "66980"
ROBINSON_CITY = "67180"
ROCKLAKE_CITY = "67500"
ROGERS_CITY = "67620"
ROLETTE_CITY = "67780"
ROLLA_CITY = "67820"
ROSS_CITY = "68540"
RUGBY_CITY = "68860"
RUSO_CITY = "69140"
RUTHVILLE_CDP = "69300"
RUTLAND_CITY = "69340"
RYDER_CITY = "69460"
SANBORN_CITY = "70380"
SARLES_CITY = "70780"
SAWYER_CITY = "70980"
SCRANTON_CITY = "71500"
SELFRIDGE_CITY = "71660"
SELZ_CDP = "71700"
SENTINEL_BUTTE_CITY = "71780"
SHARON_CITY = "71940"
SHELDON_CITY = "72180"
SHELL_VALLEY_CDP = "72250"
SHERWOOD_CITY = "72540"
SHEYENNE_CITY = "72580"
SIBLEY_CITY = "72820"
SOLEN_CITY = "73820"
SOURIS_CITY = "74020"
SOUTH_HEART_CITY = "74185"
SPIRITWOOD_CDP = "74660"
SPIRITWOOD_LAKE_CITY = "74740"
SPRINGBROOK_CITY = "74780"
ST_JOHN_CITY = "69980"
ST_THOMAS_CITY = "70260"
STANLEY_CITY = "75380"
STANTON_CITY = "75420"
STARKWEATHER_CITY = "75580"
STEELE_CITY = "75780"
STRASBURG_CITY = "76500"
STREETER_CITY = "76620"
SURREY_CITY = "77180"
SUTTON_CDP = "77260"
SYKESTON_CITY = "77660"
TAPPEN_CITY = "77980"
TAYLOR_CITY = "78180"
THOMPSON_CITY = "78660"
TIOGA_CITY = "78940"
TOLLEY_CITY = "79140"
TOLNA_CITY = "79180"
TOWER_CITY_CITY = "79340"
TOWNER_CITY = "79420"
TRENTON_CDP = "79460"
TURTLE_LAKE_CITY = "79940"
TUTTLE_CITY = "80140"
UNDERWOOD_CITY = "80660"
UPHAM_CITY = "80860"
VALLEY_CITY_CITY = "81180"
VELVA_CITY = "81620"
VENTURIA_CITY = "81700"
VERONA_CITY = "81900"
VOLTAIRE_CITY = "82380"
WAHPETON_CITY = "82660"
WALCOTT_CITY = "82780"
WALES_CITY = "82940"
WALHALLA_CITY = "82980"
WARWICK_CITY = "83580"
WASHBURN_CITY = "83700"
WATFORD_CITY_CITY = "83860"
WEST_FARGO_CITY = "84780"
WESTHOPE_CITY = "85020"
WHEATLAND_CDP = "85180"
WHITE_EARTH_CITY = "85540"
WHITE_SHIELD_CDP = "85660"
WILDROSE_CITY = "86020"
WILLISTON_CITY = "86220"
WILLOW_CITY_CITY = "86380"
WILTON_CITY = "86580"
WIMBLEDON_CITY = "86620"
WING_CITY = "86780"
WISHEK_CITY = "87020"
WOLFORD_CITY = "87180"
WOODWORTH_CITY = "87580"
WYNDMERE_CITY = "87740"
YORK_CITY = "87860"
YPSILANTI_CDP = "88020"
ZAP_CITY = "88140"
ZEELAND_CITY = "88180"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Louisiana."""


ABBEVILLE_CITY = "00100"
ABITA_SPRINGS_TOWN = "00240"
ADDIS_TOWN = "00415"
ALBANY_TOWN = "00835"
ALEXANDRIA_CITY = "00975"
AMA_CDP = "01780"
AMELIA_CDP = "01815"
AMITE_CITY_TOWN = "01885"
ANACOCO_VILLAGE = "01920"
ANGIE_VILLAGE = "02165"
ARABI_CDP = "02550"
ARCADIA_TOWN = "02655"
ARNAUDVILLE_TOWN = "03110"
ASHLAND_VILLAGE = "03145"
ATHENS_VILLAGE = "03320"
ATLANTA_VILLAGE = "03390"
AVONDALE_CDP = "03810"
BAKER_CITY = "03985"
BALDWIN_TOWN = "04020"
BALL_TOWN = "04055"
BANKS_SPRINGS_CDP = "04230"
BARATARIA_CDP = "04300"
BASILE_TOWN = "04580"
BASKIN_VILLAGE = "04615"
BASTROP_CITY = "04685"
BATON_ROUGE_CITY = "05000"
BAWCOMVILLE_CDP = "05105"
BAYOU_BLUE_CDP = "05175"
BAYOU_CANE_CDP = "05210"
BAYOU_CORNE_CDP = "05255"
BAYOU_COUNTRY_CLUB_CDP = "05260"
BAYOU_GAUCHE_CDP = "05315"
BAYOU_GOULA_CDP = "05350"
BAYOU_LOURSE_CDP = "05378"
BAYOU_VISTA_CDP = "05525"
BELCHER_VILLAGE = "05945"
BELLE_CHASSE_CDP = "06120"
BELLE_ROSE_CDP = "06260"
BELMONT_CDP = "06750"
BENTON_TOWN = "06925"
BERNICE_TOWN = "07030"
BERWICK_TOWN = "07100"
BIENVILLE_VILLAGE = "07205"
BLANCHARD_TOWN = "07730"
BOGALUSA_CITY = "08150"
BONITA_VILLAGE = "08535"
BOOTHVILLE_CDP = "08710"
BORDELONVILLE_CDP = "08745"
BOSSIER_CITY_CITY = "08920"
BOURG_CDP = "09095"
BOUTTE_CDP = "09130"
BOYCE_TOWN = "09165"
BRANCH_CDP = "09235"
BREAUX_BRIDGE_CITY = "09340"
BRIDGE_CITY_CDP = "09480"
BROUSSARD_CITY = "10075"
BROWNFIELDS_CDP = "10145"
BROWNSVILLE_CDP = "10225"
BRUSLY_TOWN = "10600"
BRYCELAND_VILLAGE = "10705"
BUNKIE_CITY = "10950"
BURAS_CDP = "10985"
CADE_CDP = "11580"
CALHOUN_CDP = "11825"
CALVIN_VILLAGE = "11930"
CAMERON_CDP = "12000"
CAMPTI_TOWN = "12280"
CANKTON_VILLAGE = "12420"
CARENCRO_CITY = "12665"
CARLYSS_CDP = "12840"
CASTOR_VILLAGE = "13260"
CATAHOULA_CDP = "13330"
CECILIA_CDP = "13575"
CENTER_POINT_CDP = "13855"
CENTERVILLE_CDP = "13925"
CENTRAL_CITY = "13960"
CHACKBAY_CDP = "14100"
CHALMETTE_CDP = "14135"
CHARENTON_CDP = "14310"
CHATAIGNIER_VILLAGE = "14450"
CHATHAM_TOWN = "14485"
CHAUVIN_CDP = "14520"
CHENEYVILLE_TOWN = "14660"
CHOCTAW_CDP = "15150"
CHOUDRANT_VILLAGE = "15290"
CHURCH_POINT_TOWN = "15465"
CLAIBORNE_CDP = "15605"
CLARENCE_VILLAGE = "15745"
CLARKS_VILLAGE = "15780"
CLAYTON_TOWN = "15850"
CLINTON_TOWN = "15990"
COLFAX_TOWN = "16375"
COLLINSTON_VILLAGE = "16655"
COLUMBIA_TOWN = "16830"
CONVENT_CDP = "17180"
CONVERSE_VILLAGE = "17215"
COTTON_VALLEY_TOWN = "17915"
COTTONPORT_TOWN = "17880"
COUSHATTA_TOWN = "18055"
COVINGTON_CITY = "18125"
CREOLA_VILLAGE = "18295"
CRESCENT_CDP = "18335"
CROWLEY_CITY = "18650"
CULLEN_TOWN = "18790"
CUT_OFF_CDP = "18930"
DARROW_CDP = "19490"
DEQUINCY_CITY = "20575"
DERIDDER_CITY = "20610"
DELACROIX_CDP = "20050"
DELCAMBRE_TOWN = "20155"
DELHI_TOWN = "20190"
DELTA_VILLAGE = "20330"
DENHAM_SPRINGS_CITY = "20435"
DES_ALLEMANDS_CDP = "20680"
DESTREHAN_CDP = "20820"
DEVILLE_CDP = "20890"
DIXIE_INN_VILLAGE = "21135"
DODSON_VILLAGE = "21170"
DONALDSONVILLE_CITY = "21240"
DORSEYVILLE_CDP = "21388"
DOWNSVILLE_VILLAGE = "21450"
DOYLINE_VILLAGE = "21590"
DRY_PRONG_VILLAGE = "21765"
DUBACH_TOWN = "21800"
DUBBERLY_VILLAGE = "21835"
DULAC_CDP = "21940"
DUSON_TOWN = "22255"
EAST_HODGE_VILLAGE = "22465"
EASTWOOD_CDP = "22610"
ECHO_CDP = "22640"
EDEN_ISLE_CDP = "22722"
EDGARD_CDP = "22815"
EDGEFIELD_VILLAGE = "22850"
EGAN_CDP = "23025"
ELIZABETH_VILLAGE = "23235"
ELMWOOD_CDP = "23567"
ELTON_TOWN = "23620"
EMPIRE_CDP = "23725"
EPPS_VILLAGE = "24145"
ERATH_TOWN = "24180"
EROS_TOWN = "24215"
ERWINVILLE_CDP = "24250"
ESTELLE_CDP = "24390"
ESTHERWOOD_VILLAGE = "24460"
EUNICE_CITY = "24565"
EVERGREEN_TOWN = "24775"
FARMERVILLE_TOWN = "25160"
FENTON_VILLAGE = "25335"
FERRIDAY_TOWN = "25440"
FIFTH_WARD_CDP = "25545"
FISHER_VILLAGE = "25615"
FLORIEN_VILLAGE = "25860"
FOLSOM_VILLAGE = "26140"
FORDOCHE_TOWN = "26280"
FOREST_HILL_VILLAGE = "26420"
FOREST_VILLAGE = "26350"
FORT_JESUP_CDP = "26665"
FORT_POLK_NORTH_CDP = "26746"
FORT_POLK_SOUTH_CDP = "26757"
FRANKLIN_CITY = "27155"
FRANKLINTON_TOWN = "27190"
FRENCH_SETTLEMENT_VILLAGE = "27435"
FRIERSON_CDP = "27540"
GALLIANO_CDP = "28065"
GARDERE_CDP = "28275"
GARYVILLE_CDP = "28345"
GEORGETOWN_VILLAGE = "28660"
GIBSLAND_TOWN = "28835"
GILBERT_VILLAGE = "28940"
GILLIAM_VILLAGE = "29010"
GILLIS_CDP = "29045"
GLENCOE_CDP = "29150"
GLENMORA_TOWN = "29220"
GLOSTER_CDP = "29395"
GOLDEN_MEADOW_TOWN = "29640"
GOLDONNA_VILLAGE = "29745"
GONZALES_CITY = "29850"
GOOD_PINE_CDP = "29990"
GRAMBLING_CITY = "30515"
GRAMERCY_TOWN = "30550"
GRAND_CANE_VILLAGE = "30690"
GRAND_COTEAU_TOWN = "30760"
GRAND_ISLE_TOWN = "30830"
GRAND_POINT_CDP = "30900"
GRAY_CDP = "31180"
GRAYSON_VILLAGE = "31250"
GREENSBURG_TOWN = "31565"
GREENWOOD_TOWN = "31705"
GRETNA_CITY = "31915"
GROSSE_TETE_VILLAGE = "32020"
GUEYDAN_TOWN = "32055"
HACKBERRY_CDP = "32405"
HAHNVILLE_CDP = "32510"
HALL_SUMMIT_VILLAGE = "32650"
HAMMOND_CITY = "32755"
HARAHAN_CITY = "32930"
HARRISONBURG_VILLAGE = "33210"
HARVEY_CDP = "33245"
HAUGHTON_TOWN = "33420"
HAYES_CDP = "33490"
HAYNESVILLE_TOWN = "33525"
HEFLIN_VILLAGE = "33735"
HENDERSON_TOWN = "33875"
HESSMER_VILLAGE = "34015"
HESTER_CDP = "34085"
HODGE_VILLAGE = "35100"
HOMER_TOWN = "35870"
HORNBECK_TOWN = "36045"
HOSSTON_VILLAGE = "36150"
HOUMA_CITY = "36255"
IDA_VILLAGE = "36885"
INDEPENDENCE_TOWN = "37025"
INNISWOLD_CDP = "37270"
IOTA_TOWN = "37410"
IOWA_TOWN = "37445"
JACKSON_TOWN = "37830"
JAMESTOWN_VILLAGE = "37935"
JEAN_LAFITTE_TOWN = "38092"
JEANERETTE_CITY = "38075"
JEFFERSON_CDP = "38145"
JENA_TOWN = "38285"
JENNINGS_CITY = "38355"
JONESBORO_TOWN = "38670"
JONESVILLE_TOWN = "38775"
JORDAN_HILL_CDP = "38845"
JOYCE_CDP = "38880"
JUNCTION_CITY_VILLAGE = "38985"
KAPLAN_CITY = "39055"
KEACHI_TOWN = "39085"
KENNER_CITY = "39475"
KENTWOOD_TOWN = "39545"
KILBOURNE_VILLAGE = "39650"
KILLIAN_TOWN = "39685"
KILLONA_CDP = "39720"
KINDER_TOWN = "39755"
KRAEMER_CDP = "40210"
KROTZ_SPRINGS_TOWN = "40280"
LABADIEVILLE_CDP = "40420"
LACASSINE_CDP = "40595"
LACOMBE_CDP = "40665"
LAFAYETTE_CITY = "40735"
LAFITTE_CDP = "40840"
LAFOURCHE_CROSSING_CDP = "40878"
LAKE_ARTHUR_TOWN = "41050"
LAKE_CHARLES_CITY = "41155"
LAKE_PROVIDENCE_TOWN = "41400"
LAKESHORE_CDP = "41470"
LAKEVIEW_CDP = "41645"
LAPLACE_CDP = "42030"
LAROSE_CDP = "42135"
LAWTELL_CDP = "42520"
LECOMPTE_TOWN = "42800"
LEESVILLE_CITY = "43010"
LEMANNVILLE_CDP = "43255"
LEONVILLE_TOWN = "43395"
LEWISBURG_CDP = "43640"
LILLIE_VILLAGE = "43920"
LISBON_VILLAGE = "44235"
LIVINGSTON_TOWN = "44655"
LIVONIA_TOWN = "44690"
LOCKPORT_HEIGHTS_CDP = "44970"
LOCKPORT_TOWN = "44900"
LOGANSPORT_TOWN = "45040"
LONGSTREET_VILLAGE = "45460"
LONGVILLE_CDP = "45530"
LOREAUVILLE_VILLAGE = "45670"
LUCKY_VILLAGE = "46370"
LULING_CDP = "46615"
LUTCHER_TOWN = "46720"
LYDIA_CDP = "46755"
MADISONVILLE_TOWN = "47560"
MAMOU_TOWN = "48085"
MANDEVILLE_CITY = "48225"
MANGHAM_TOWN = "48260"
MANSFIELD_CITY = "48365"
MANSURA_TOWN = "48400"
MANY_TOWN = "48470"
MARINGOUIN_TOWN = "48610"
MARION_TOWN = "48645"
MARKSVILLE_CITY = "48750"
MARRERO_CDP = "48785"
MARTHAVILLE_CDP = "48890"
MARTIN_VILLAGE = "48925"
MATHEWS_CDP = "49170"
MAURICE_VILLAGE = "49240"
MCNARY_VILLAGE = "47315"
MELVILLE_TOWN = "49730"
MER_ROUGE_VILLAGE = "49905"
MERAUX_CDP = "49800"
MERMENTAU_VILLAGE = "49870"
MERRYDALE_CDP = "49940"
MERRYVILLE_TOWN = "50010"
METAIRIE_CDP = "50115"
MIDLAND_CDP = "50325"
MIDWAY_CDP = "50395"
MILTON_CDP = "50815"
MINDEN_CITY = "50885"
MINORCA_CDP = "50990"
MONROE_CITY = "51410"
MONTEGUT_CDP = "51550"
MONTEREY_CDP = "51585"
MONTGOMERY_TOWN = "51620"
MONTICELLO_CDP = "51645"
MONTPELIER_VILLAGE = "51690"
MONTZ_CDP = "51795"
MOONSHINE_CDP = "51800"
MOORINGSPORT_TOWN = "51830"
MOREAUVILLE_VILLAGE = "51970"
MORGAN_CITY_CITY = "52040"
MORGANZA_VILLAGE = "52075"
MORROW_CDP = "52250"
MORSE_VILLAGE = "52320"
MOSS_BLUFF_CDP = "52425"
MOUND_VILLAGE = "52565"
MOUNT_LEBANON_TOWN = "52740"
NAPOLEONVILLE_VILLAGE = "53370"
NATALBANY_CDP = "53475"
NATCHEZ_VILLAGE = "53510"
NATCHITOCHES_CITY = "53545"
NEW_IBERIA_CITY = "54035"
NEW_LLANO_TOWN = "54175"
NEW_ORLEANS_STATION_CDP = "55074"
NEW_ORLEANS_CITY = "55000"
NEW_ROADS_CITY = "55105"
NEW_SARPY_CDP = "55140"
NEWELLTON_TOWN = "53930"
NOBLE_VILLAGE = "55420"
NORCO_CDP = "55525"
NORTH_HODGE_VILLAGE = "55910"
NORTH_VACHERIE_CDP = "56170"
NORWOOD_VILLAGE = "56295"
OAK_GROVE_TOWN = "56820"
OAK_HILLS_PLACE_CDP = "56855"
OAK_RIDGE_VILLAGE = "57205"
OAKDALE_CITY = "56540"
OBERLIN_TOWN = "57450"
OIL_CITY_TOWN = "57590"
OLD_JEFFERSON_CDP = "57705"
OLLA_TOWN = "57905"
OPELOUSAS_CITY = "58045"
ORETTA_CDP = "58150"
OSSUN_CDP = "58360"
PAINCOURTVILLE_CDP = "58745"
PALMETTO_VILLAGE = "58780"
PARADIS_CDP = "58920"
PARKS_VILLAGE = "59165"
PATTERSON_CITY = "59340"
PAULINA_CDP = "59375"
PEARL_RIVER_TOWN = "59445"
PERRY_CDP = "59795"
PIERRE_PART_CDP = "60075"
PINE_PRAIRIE_VILLAGE = "60495"
PINEVILLE_CITY = "60530"
PIONEER_VILLAGE = "60565"
PITKIN_CDP = "60600"
PLAIN_DEALING_TOWN = "60670"
PLAQUEMINE_CITY = "60880"
PLAUCHEVILLE_VILLAGE = "60985"
PLEASANT_HILL_VILLAGE = "61055"
PLEASURE_BEND_CDP = "61160"
POINT_PLACE_CDP = "61473"
POINTE_A_LA_HACHE_CDP = "61440"
POLLOCK_TOWN = "61580"
PONCHATOULA_CITY = "61615"
PORT_ALLEN_CITY = "61790"
PORT_BARRE_TOWN = "61825"
PORT_SULPHUR_CDP = "62070"
PORT_VINCENT_VILLAGE = "62105"
POWHATAN_VILLAGE = "62245"
POYDRAS_CDP = "62280"
PRAIRIEVILLE_CDP = "62385"
PRESQUILLE_CDP = "62510"
PRIEN_CDP = "62647"
PROSPECT_CDP = "62733"
PROVENCAL_VILLAGE = "62770"
QUITMAN_VILLAGE = "63120"
RACELAND_CDP = "63155"
RAYNE_CITY = "63645"
RAYVILLE_TOWN = "63680"
RED_CHUTE_CDP = "63855"
REDDELL_CDP = "63890"
REEVES_VILLAGE = "64100"
RESERVE_CDP = "64310"
RICHMOND_VILLAGE = "64590"
RICHWOOD_TOWN = "64660"
RIDGECREST_TOWN = "64765"
RINGGOLD_TOWN = "64905"
RIO_CDP = "64975"
RIVER_RIDGE_CDP = "65150"
ROANOKE_CDP = "65290"
ROBELINE_VILLAGE = "65325"
ROCK_HILL_CDP = "65535"
RODESSA_VILLAGE = "65710"
ROMEVILLE_CDP = "65850"
ROSEDALE_VILLAGE = "66060"
ROSELAND_TOWN = "66165"
ROSEPINE_TOWN = "66200"
RUSTON_CITY = "66655"
SALINE_VILLAGE = "67880"
SAREPTA_TOWN = "68125"
SCHRIEVER_CDP = "68300"
SCOTT_CITY = "68475"
SHENANDOAH_CDP = "69225"
SHONGALOO_VILLAGE = "69455"
SHREVEPORT_CITY = "70000"
SIBLEY_TOWN = "70175"
SICILY_ISLAND_VILLAGE = "70245"
SIKES_VILLAGE = "70385"
SIMMESPORT_TOWN = "70525"
SIMPSON_VILLAGE = "70595"
SIMSBORO_VILLAGE = "70630"
SINGER_CDP = "70665"
SIRACUSAVILLE_CDP = "70675"
SLAUGHTER_TOWN = "70770"
SLIDELL_CITY = "70805"
SORREL_CDP = "71190"
SORRENTO_TOWN = "71225"
SOUTH_MANSFIELD_VILLAGE = "71820"
SOUTH_VACHERIE_CDP = "72092"
SPEARSVILLE_VILLAGE = "72170"
SPOKANE_CDP = "72310"
SPRINGFIELD_TOWN = "72415"
SPRINGHILL_CITY = "72485"
ST_FRANCISVILLE_TOWN = "67215"
ST_GABRIEL_CITY = "67250"
ST_JAMES_CDP = "67355"
ST_JOSEPH_TOWN = "67495"
ST_MARTINVILLE_CITY = "67600"
ST_MAURICE_CDP = "67635"
ST_ROSE_CDP = "67740"
STANLEY_VILLAGE = "72800"
STARKS_CDP = "72975"
START_CDP = "73010"
STERLINGTON_TOWN = "73255"
STONEWALL_TOWN = "73395"
SUGARTOWN_CDP = "73570"
SULPHUR_CITY = "73640"
SUN_VILLAGE = "73955"
SUNSET_TOWN = "74060"
SUPREME_CDP = "74235"
SWARTZ_CDP = "74340"
TAFT_CDP = "74550"
TALLULAH_CITY = "74690"
TANGIPAHOA_VILLAGE = "74760"
TERRYTOWN_CDP = "75180"
THIBODAUX_CITY = "75425"
TICKFAW_VILLAGE = "75670"
TIMBERLANE_CDP = "75740"
TRIUMPH_CDP = "76440"
TROUT_CDP = "76475"
TULLOS_TOWN = "76615"
TURKEY_CREEK_VILLAGE = "76685"
UNION_CDP = "77035"
URANIA_TOWN = "77490"
VARNADO_VILLAGE = "77910"
VENICE_CDP = "78015"
VENTRESS_CDP = "78050"
VIDALIA_TOWN = "78470"
VIENNA_BEND_CDP = "78545"
VIENNA_TOWN = "78540"
VILLAGE_ST_GEORGE_CDP = "78680"
VILLE_PLATTE_CITY = "78715"
VINTON_TOWN = "78820"
VIOLET_CDP = "78855"
VIVIAN_TOWN = "78890"
WAGGAMAN_CDP = "79100"
WALKER_TOWN = "79240"
WALLACE_CDP = "79275"
WALLACE_RIDGE_CDP = "79310"
WASHINGTON_TOWN = "79870"
WATERPROOF_TOWN = "79940"
WATSON_CDP = "80010"
WELCOME_CDP = "80360"
WELSH_TOWN = "80430"
WEST_MONROE_CITY = "80955"
WESTLAKE_CITY = "80815"
WESTMINSTER_CDP = "80920"
WESTWEGO_CITY = "81165"
WHITE_CASTLE_TOWN = "81375"
WILSON_VILLAGE = "82215"
WINNFIELD_CITY = "82460"
WINNSBORO_CITY = "82495"
WISNER_TOWN = "82565"
WOODMERE_CDP = "83002"
WOODWORTH_TOWN = "83125"
YOUNGSVILLE_CITY = "83335"
ZACHARY_CITY = "83405"
ZWOLLE_TOWN = "83685"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Louisiana."""


ACADIA = "001"
ALLEN = "003"
ASCENSION = "005"
ASSUMPTION = "007"
AVOYELLES = "009"
BEAUREGARD = "011"
BIENVILLE = "013"
BOSSIER = "015"
CADDO = "017"
CALCASIEU = "019"
CALDWELL = "021"
CAMERON = "023"
CATAHOULA = "025"
CLAIBORNE = "027"
CONCORDIA = "029"
DE_SOTO = "031"
EAST_BATON_ROUGE = "033"
EAST_CARROLL = "035"
EAST_FELICIANA = "037"
EVANGELINE = "039"
FRANKLIN = "041"
GRANT = "043"
IBERIA = "045"
IBERVILLE = "047"
JACKSON = "049"
JEFFERSON_DAVIS = "053"
JEFFERSON = "051"
LASALLE = "059"
LAFAYETTE = "055"
LAFOURCHE = "057"
LINCOLN = "061"
LIVINGSTON = "063"
MADISON = "065"
MOREHOUSE = "067"
NATCHITOCHES = "069"
ORLEANS = "071"
OUACHITA = "073"
PLAQUEMINES = "075"
POINTE_COUPEE = "077"
RAPIDES = "079"
RED_RIVER = "081"
RICHLAND = "083"
SABINE = "085"
ST_BERNARD = "087"
ST_CHARLES = "089"
ST_HELENA = "091"
ST_JAMES = "093"
ST_JOHN_THE_BAPTIST = "095"
ST_LANDRY = "097"
ST_MARTIN = "099"
ST_MARY = "101"
ST_TAMMANY = "103"
TANGIPAHOA = "105"
TENSAS = "107"
TERREBONNE = "109"
UNION = "111"
VERMILION = "113"
VERNON = "115"
WASHINGTON = "117"
WEBSTER = "119"
WEST_BATON_ROUGE = "121"
WEST_CARROLL = "123"
WEST_FELICIANA = "125"
WINN = "127"



# Copyright (c) 2022 Darren Erik Vengroff
"""Variable cache code to cache metatada about variables locally."""

from collections import defaultdict
from logging import getLogger
from typing import Any, DefaultDict, Dict, Generator, Iterable, List, Optional, Tuple

import numpy as np
import pandas as pd

from censusdis.impl.varsource.base import VariableSource
from censusdis.impl.varsource.censusapi import CensusApiVariableSource

import censusdis.datasets


logger = getLogger(__name__)


class VariableCache:
    """
    A cache of variables and groups.

    This looks a lot like a :py:class:`~VariableSource` but it
    implements a cache in front of a :py:class:`~VariableSource`.

    Users will rarely if ever need to construct one of these
    themselves. In almost all cases they will use the singleton
    `censusdis.censusdata.variables`.
    """

    def __init__(self, *, variable_source: Optional[VariableSource] = None):
        if variable_source is None:
            variable_source = CensusApiVariableSource()

        self._variable_source = variable_source
        self._variable_cache: DefaultDict[str, DefaultDict[int, Dict[str, Any]]] = (
            defaultdict(lambda: defaultdict(dict))
        )
        self._group_cache: DefaultDict[str, DefaultDict[int, Dict[str, Any]]] = (
            defaultdict(lambda: defaultdict(dict))
        )

        self._all_data_sets_cache: Optional[pd.DataFrame] = None
        self._data_sets_by_year_cache: Dict[int, pd.DataFrame] = {}

    def get(
        self,
        dataset: str,
        year: int,
        name: str,
    ) -> Dict[str, Dict]:
        """
        Get the description of a given variable.

        See :py:meth:`VariableSource.get`
        for details on the data format. We first look in the cache and then if
        we don't find what we are looking for, we call the source behind us and
        cache the results before returning them.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year
        name
            The name of the variable.

        Returns
        -------
            The details of the variable.
        """
        cached_value = self._variable_cache[dataset][year].get(name, None)

        if cached_value is not None:
            return cached_value

        value = self._variable_source.get(dataset, year, name)

        self._variable_cache[dataset][year][name] = value

        return value

    def get_group(
        self,
        dataset: str,
        year: int,
        name: Optional[str],
    ) -> Dict[str, Dict]:
        """
        Get information on the variables in a group.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year
        name
            The name of the group. Or None if this data set does not have
            groups.

        Returns
        -------
            A dictionary that maps from the names of each variable in the group
            to a dictionary containing a description of the variable. The
            format of the description is a dictionary as described in
            the documentation for
            :py:meth:`VariableSource.get`.
        """
        group_variable_names = self._group_cache[dataset][year].get(name, None)

        if group_variable_names is None:
            # Missed in the cache, so go fetch it.
            value = self._variable_source.get_group(dataset, year, name)

            # Cache all the variables in the group.
            group_variables = value["variables"]

            for variable_name, variable_details in group_variables.items():
                self._variable_cache[dataset][year][variable_name] = variable_details

            # Cache the names of the variables in the group.
            group_variable_names = list(
                variable_name for variable_name in group_variables
            )
            self._group_cache[dataset][year][name] = group_variable_names

        # Reformat what we return so it includes the full
        # details on each variable.
        return {
            group_variable_name: self.get(dataset, year, group_variable_name)
            for group_variable_name in group_variable_names
        }

    class GroupTreeNode:
        """A node in a tree of variables that make up a group."""

        def __init__(self, name: Optional[str] = None):
            self._name = name

            self._children: Dict[str, "VariableCache.GroupTreeNode"] = {}

        @property
        def name(self):
            """The name of the node."""
            return self._name

        @name.setter
        def name(self, name: Optional[str]):
            self._name = name

        def add_child(self, path_component: str, child: "VariableCache.GroupTreeNode"):
            """
            Add a child to a node.

            Parameters
            ----------
            path_component
                The next component of the path to the variable, beyond the
                path to `self`.
            child
                The node that should be our child at the specified path component.

            Returns
            -------
                None
            """
            self._children[path_component] = child

        def is_leaf(self) -> bool:
            """
            Is the node a leaf.

            Returns
            -------
                `True` if it is a leaf; `False` if it is an internal node.
            """
            return len(self._children) == 0

        def __len__(self):
            """Return the number of children the node has."""
            return len(self._children)

        def __contains__(self, component: str):
            """Determine if a component is in the node."""
            return component in self._children

        def __getitem__(self, component: str):
            """Get a child of a node."""
            return self._children[component]

        def keys(self) -> Generator[str, None, None]:
            """
            Return the keys, which are the strings of the next component to each child.

            Returns
            -------
                The keys
            """
            for key, _ in self.items():
                yield key

        def values(self) -> Generator["VariableCache.GroupTreeNode", None, None]:
            """
            Return the values, which are our children.

            Returns
            -------
                The values (our children).
            """
            for _, value in self.items():
                yield value

        def items(
            self,
        ) -> Generator[Tuple[str, "VariableCache.GroupTreeNode"], None, None]:
            """
            Retudn the items.

            The items are (key, value) pairs. See :py:meth:`keys` and
            :py:meth:`values`.

            Returns
            -------
                The items
            """
            for component, node in self._children.items():
                yield component, node

        def get(
            self, component, default: Optional["VariableCache.GroupTreeNode"] = None
        ):
            """
            Get the child at the given path component below us.

            Parameters
            ----------
            component
                The next component of the path below us.
            default
                The default value to return if there is no node at the path.

            Returns
            -------
                The node below us or `default` if it is not there,
            """
            return self._children.get(component, default)

        def leaves(self) -> Generator["VariableCache.GroupTreeNode", None, None]:
            """
            Return all the leaves below us.

            Compare with :py:meth:`~leaf_variables`
            which returns just the names of the leaves.

            Returns
            -------
                All the leaves below us.
            """
            if self.is_leaf():
                yield self
            for child in self._children.values():
                yield from child.leaves()

        def leaf_variables(self) -> Generator[str, None, None]:
            """
            Return the names of all the leaves below us.

            Compare with :py:meth:`~leaves`
            which returns the full node for each leaf.

            Returns
            -------
                The names of the leaves below us.
            """
            yield from (leaf.name for leaf in self.leaves())

        @property
        def min_leaf_name(self) -> str:
            """The name of the first leaf."""
            return min(self.leaf_variables())

        def _node_str(self, level: int, component: str, indent_prefix: str) -> str:
            line = indent_prefix * level
            if len(self._children) > 0 or self._name is not None:
                line = f"{line}+ {component}"
            if self.name is not None:
                line = f"{line} ({self.name})"

            return line

        def subtree_str(self, level: int, component: str, indent_prefix: str) -> str:
            """
            Return a string representing a subtree.

            Used to construct an indented string representation for the whole tree.
            """
            rep = self._node_str(level, component, indent_prefix)
            for path_component, child in sorted(
                self._children.items(), key=lambda t: t[1].min_leaf_name
            ):
                rep = (
                    rep
                    + "\n"
                    + child.subtree_str(level + 1, path_component, indent_prefix)
                )
            return rep

        def __str__(self) -> str:
            """Return a string representation of the node."""
            return "\n".join(
                child.subtree_str(0, path_component, indent_prefix="    ")
                for path_component, child in sorted(
                    self._children.items(), key=lambda t: t[1].min_leaf_name
                )
            )

        def __repr__(self) -> str:
            """Return the representation of the node."""
            return str(self)

    def _all_data_sets(self) -> pd.DataFrame:
        """
        Get all the data sets.

        Cache to avoid repeated remote calls.

        Returns
        -------
            A data frame of all the data sets for all years.
        """
        if self._all_data_sets_cache is None:
            datasets = self._variable_source.get_datasets(year=None)

            self._all_data_sets_cache = self._datasets_from_source_dict(datasets)

        return self._all_data_sets_cache

    def _data_sets_for_year(self, year: int) -> pd.DataFrame:
        """
        Get all data sets for a given year.

        Cache to avoid repeated remote calls.

        Parameters
        ----------
        year
            The year to query. If not provided, all data sets for all
            years are queried.

        Returns
        -------
            A data frame of all the data sets for the year.
        """
        if year not in self._data_sets_by_year_cache:
            datasets = self._variable_source.get_datasets(year)

            self._data_sets_by_year_cache[year] = self._datasets_from_source_dict(
                datasets
            )

        return self._data_sets_by_year_cache[year]

    @staticmethod
    def _datasets_from_source_dict(datasets) -> pd.DataFrame:
        """
        Parse a dict from :py:meth:`VariableSource.get_datasets` into a data frame of data sets.

        Parameters
        ----------
        datasets
            The data sets in dictionary form.

        Returns
        -------
            A dataframe with a row describing each dataset.
        """
        datasets = datasets["dataset"]
        df_datasets = pd.DataFrame(
            [
                {
                    "YEAR": dataset.get(
                        "c_vintage",
                        "timeseries" if dataset.get("c_isTimeseries", False) else None,
                    ),
                    "DATASET": "/".join(dataset["c_dataset"]),
                    "TITLE": dataset.get("title", None),
                    "DESCRIPTION": dataset.get("description", None),
                    "API BASE URL": (
                        dataset["distribution"][0].get("accessURL", None)
                        if dataset.get("distribution")
                        else None
                    ),
                }
                for dataset in datasets
            ]
        )

        symbol_dict_reversed = {
            value: symbol
            for symbol, value in censusdis.datasets.__dict__.items()
            if isinstance(value, str)
        }

        df_datasets["SYMBOL"] = df_datasets["DATASET"].apply(
            lambda name: symbol_dict_reversed.get(name, None)
        )

        df_datasets = df_datasets[
            ["YEAR", "SYMBOL", "DATASET"]
            + [
                col
                for col in df_datasets.columns
                if col not in ["YEAR", "SYMBOL", "DATASET"]
            ]
        ]

        return df_datasets.sort_values(["YEAR", "DATASET"]).reset_index(drop=True)

    def all_data_sets(self, *, year: Optional[int] = None) -> pd.DataFrame:
        """
        Retrieve a description of available data sets.

        Parameters
        ----------
        year
            The year to query. If not provided, all data sets for all
            years are queried.

        Returns
        -------
            A data frame describing the data sets that are available.
        """
        if year is not None:
            return self._data_sets_for_year(year)

        return self._all_data_sets()

    def all_groups(
        self,
        dataset: str,
        year: int,
    ) -> pd.DataFrame:
        """
        Get descriptions of all the groups in the data set.

        Parameters
        ----------
        dataset
            The data set.
        year
            The year.

        Returns
        -------
            Metadata on all the groups in the data set.
        """
        groups = self._variable_source.get_all_groups(dataset, year)

        # Some data sets have no groups.
        if len(groups["groups"]) == 0:
            return pd.DataFrame(columns=["DATASET", "YEAR", "GROUP", "DESCRIPTION"])

        return (
            pd.DataFrame(
                [
                    {
                        "DATASET": dataset,
                        "YEAR": year,
                        "GROUP": group["name"],
                        "DESCRIPTION": group["description"],
                    }
                    for group in groups["groups"]
                ]
            )
            .sort_values(["DATASET", "YEAR", "GROUP"])
            .reset_index(drop=True)
        )

    def all_variables(
        self, dataset: str, year: int, group_name: Optional[str]
    ) -> pd.DataFrame:
        """
        Produce a data frame of metadata on all variables in a group.

        Parameters
        ----------
        dataset
            The data set.
        year
            The year.
        group_name
            The group.

        Returns
        -------
            Metadata on all variables in the group.
        """
        group_variables = self.group_variables(dataset, year, group_name)

        def variable_items(variable_dict: Dict) -> Optional[Dict[str, str]]:
            if "values" in variable_dict:
                values = variable_dict["values"]
                return values.get("item", np.nan)

            return None

        return pd.DataFrame(
            [
                {
                    "YEAR": year,
                    "DATASET": dataset,
                    "GROUP": self.get(dataset, year, variable_name).get(
                        "group", np.nan
                    ),
                    "VARIABLE": variable_name,
                    "LABEL": self.get(dataset, year, variable_name)["label"],
                    "SUGGESTED_WEIGHT": self.get(dataset, year, variable_name).get(
                        "suggested-weight", np.nan
                    ),
                    "VALUES": variable_items(self.get(dataset, year, variable_name)),
                }
                for variable_name in group_variables
            ]
        )

    def group_tree(
        self,
        dataset: str,
        year: int,
        group_name: Optional[str],
        *,
        skip_annotations: bool = True,
    ) -> "VariableCache.GroupTreeNode":
        """
        Construct a tree that embodies the parent/child relationships of all the variables in a group.

        Parameters
        ----------
        dataset
            The data set.
        year
            The year.
        group_name
            The group.
        skip_annotations
            If `True`, skip variables that are annotations of others, like
            margin of error.

        Returns
        -------
            A tree that can be printed or walked.
        """
        group = self.get_group(dataset, year, group_name)

        root = VariableCache.GroupTreeNode()

        for variable_name, details in group.items():
            path = details["label"].split("!!")

            if skip_annotations and (
                path[0].startswith("Annotation")
                or path[0].startswith("Margin of Error")
                or path[0].startswith("Statistical Significance")
            ):
                continue

            node = root

            # Construct a nested path of nodes down to the
            # leaf.
            for component in path:
                child = node.get(component, None)
                if child is None:
                    child = VariableCache.GroupTreeNode()
                    node.add_child(component, child)
                node = child

            # Put the variable name at the lead.
            node.name = variable_name

        return root

    def group_leaves(
        self, dataset: str, year: int, name: str, *, skip_annotations: bool = True
    ) -> List[str]:
        """
        Find the leaves of a given group.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year
        name
            The name of the group.
        skip_annotations
            If `True` try to filter out variables that are
            annotations rather than actual values, by skipping
            those with labels that begin with "Annotation" or
            "Margin of Error".

        Returns
        -------
            A list of the variables in the group that are leaves,
            i.e. they are not aggregates of other variables. For example,
            in the group `B03002` in the `acs/acs5` dataset in the
            year `2020`, the variable `B03002_003E` is a leaf, because
            it represents
            "Estimate!!Total:!!Not Hispanic or Latino:!!White alone",
            whereas B03002_002E is not a leaf because it represents
            "Estimate!!Total:!!Not Hispanic or Latino:", which is a total
            that includes B03002_003E as well as others like "B03002_004E",
            "B03002_005E" and more.

            The typical reason we want leaves is because that gives us a set
            of variables representing counts that do not overlap and add up
            to the total. We can use these directly in diversity and integration
            calculations using the `divintseg` package.
        """
        tree = self.group_tree(dataset, year, name)

        leaves = tree.leaf_variables()

        if skip_annotations:
            group = self.get_group(dataset, year, name)
            leaves = (
                leaf
                for leaf in leaves
                if (not group[leaf]["label"].startswith("Annotation"))
                and (not group[leaf]["label"].startswith("Margin of Error"))
            )

        return sorted(leaves)

    def group_variables(
        self, dataset: str, year: int, group_name: str, *, skip_annotations: bool = True
    ) -> List[str]:
        """
        Find the variables of a given group.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year
        group_name
            The name of the group.
        skip_annotations
            If `True` try to filter out variables that are
            annotations rather than actual values, by skipping
            those with labels that begin with "Annotation" or
            "Margin of Error".

        Returns
        -------
            A list of the variables in the group.
        """
        tree = self.get_group(dataset, year, group_name)

        if skip_annotations:
            group_variables = [
                k
                for k, v in tree.items()
                if (not v["label"].startswith("Annotation"))
                and (not v["label"].startswith("Margin of Error"))
            ]
        else:
            group_variables = list(tree.keys())

        return sorted(group_variables)

    def __contains__(self, item: Tuple[str, int, str]) -> bool:
        """Magic method behind the `in` operator."""
        source, year, name = item

        return name in self._variable_cache[source][year]

    def __getitem__(self, item: Tuple[str, int, str]):
        """Magic method behind the `[]` operator."""
        return self.get(*item)

    def __len__(self):
        """Return he number of elements in the cache."""
        return sum(
            len(names)
            for years in self._variable_cache.values()
            for names in years.values()
        )

    def keys(self) -> Iterable[Tuple[str, int, str]]:
        """Keys, i.e. the names of variables, in the cache."""
        for key, _ in self.items():
            yield key

    def __iter__(self) -> Iterable[Tuple[str, int, str]]:
        """Return an iterator over the keys."""
        return self.keys()

    def values(self) -> Iterable[dict]:
        """Values, i.e. the descriptions of variables, in the cache."""
        for _, value in self.items():
            yield value

    def items(self) -> Iterable[Tuple[Tuple[str, int, str], dict]]:
        """Items in the mapping from variable name to descpription."""
        for source, values_for_source in self._variable_cache.items():
            for year, values_for_year in values_for_source.items():
                for name, value in values_for_year.items():
                    yield (source, year, name), value

    def invalidate(self, dataset: str, year: int, name: str):
        """Remove an item from the cache."""
        if self._variable_cache[dataset][year].pop(name, None):
            if len(self._variable_cache[dataset][year]) == 0:
                self._variable_cache[dataset].pop(year)
                if len(self._variable_cache[dataset]) == 0:
                    self._variable_cache.pop(dataset)

    def clear(self):
        """
        Clear the entire cache.

        This just means that further calls to :py:meth:`~get` will
        have to make a call to the source behind the cache.
        """
        self._variable_cache = defaultdict(lambda: defaultdict(dict))
